@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: bookmark.tabs.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: bookmark.tabs.php 11396 2010-04-27 17:50:23Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -34,16 +34,18 @@
 // ----------------------------------------------------------------------
 
 
-$NEEDED_ITEMS=array("profile","search","entity","user");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
+if (!isset($_REQUEST['glpi_tab'])) {
+   exit();
+}
+
 
 $bookmark = new Bookmark;
-$bookmark->showBookmarkList($_POST['target'],$_POST['glpi_tab']);
+$bookmark->showBookmarkList($_POST['target'],$_REQUEST['glpi_tab']);
 
 ajaxFooter();
-?>
\ No newline at end of file
+?>
