@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computerdisk.tabs.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: computerdisk.tabs.php 11396 2010-04-27 17:50:23Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,20 +33,28 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
-if(isset($_POST["ID"]) && $_POST['ID']>0) {
-	switch($_POST['glpi_tab']){
-		default :
-			if (!displayPluginAction(COMPUTERDISK_TYPE,$_POST["ID"],$_POST['glpi_tab'])){
-			}
-			break;
-	}	
+if (!isset($_POST['id'])) {
+   exit();
 }
 
-ajaxFooter();		
+if (!isset($_REQUEST['glpi_tab'])) {
+   exit();
+}
+
+
+$disk = new ComputerDisk();
+if (isset($_POST["id"]) && $_POST['id']>0 && $disk->can($_POST['id'],'r')) {
+   switch($_REQUEST['glpi_tab']) {
+      default :
+         if (!Plugin::displayAction($disk, $_REQUEST['glpi_tab'])) {
+         }
+   }
+}
+
+ajaxFooter();
 ?>
