@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: config.tabs.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: config.tabs.php 11683 2010-06-11 20:44:24Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,48 +33,62 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$NEEDED_ITEMS = array (
-	"setup",
-	"ocsng",
-	"dbreplicate"
-);
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
-if(!isset($_POST["ID"])) {
-	exit();
+if (!isset($_POST["id"])) {
+   exit();
 }
 
-	checkRight("config", "r");
-	
-	$config = new Config();
-	
-	if ($_POST["ID"]<0){
-			switch($_POST['glpi_tab']){
-				case 1 :
-					$config->showFormMain($_POST['target']);
-					break;
-				case 2 :
-					$config->showFormDisplay($_POST['target']);
-					break;
-				case 3 :
-					$config->showFormRestrict($_POST['target']);
-					break;
-				case 4 :
-					$config->showFormConnection($_POST['target']);
-					break;
-				case 5 :
-					$config->showFormDBSlave($_POST['target']);
-					break;
-				case 6 :
-					$config->showFormUserPrefs($_POST['target'],$CFG_GLPI);
-					break;
-				default :
-					break;
-		}
-	}
+checkRight("config", "r");
 
-?>
\ No newline at end of file
+$config = new Config();
+
+switch($_REQUEST['glpi_tab']) {
+   case -1 :
+      $config->showFormDisplay();
+      $config->showFormUserPrefs($CFG_GLPI);
+      $config->showFormInventory();
+      $config->showFormHelpdesk();
+      $config->showSystemInformations();
+      if (DBConnection::isDBSlaveActive()) {
+         $config->showFormDBSlave();
+      }
+      Plugin::displayAction($config,$_REQUEST['glpi_tab']);
+      break;
+
+   case 1 :
+      $config->showFormDisplay();
+      break;
+
+   case 2 :
+      $config->showFormUserPrefs($CFG_GLPI);
+      break;
+
+   case 3 :
+      $config->showFormInventory();
+      break;
+
+   case 4 :
+      $config->showFormHelpdesk();
+      break;
+
+   case 5 :
+      $config->showSystemInformations();
+      break;
+
+   case 6 :
+      $config->showFormDBSlave();
+      break;
+
+
+   default :
+      if (!Plugin::displayAction($config,$_REQUEST['glpi_tab'])) {
+      $config->showFormDisplay();
+      }
+}
+
+ajaxFooter();
+?>
