@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contact.tabs.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: contact.tabs.php 11396 2010-04-27 17:50:23Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,43 +33,55 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$NEEDED_ITEMS=array("contact","enterprise","link","document");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
-if(!isset($_POST["ID"])) {
-	exit();
+if (!isset($_POST["id"])) {
+   exit();
+}
+if (!isset($_REQUEST['glpi_tab'])) {
+   exit();
 }
 
-if(empty($_POST["ID"])) $_POST["ID"] = -1;
-
-		if ($_POST['ID']>0){
-			switch($_POST['glpi_tab']){
-				case -1 :	
-					showEnterpriseContact($_POST["ID"]);
-					showDocumentAssociated(CONTACT_TYPE,$_POST["ID"]);
-					showLinkOnDevice(CONTACT_TYPE,$_POST["ID"]);
-					displayPluginAction(CONTACT_TYPE,$_POST["ID"],$_POST['glpi_tab']);
-					break;
-				case 5 : 
-					showDocumentAssociated(CONTACT_TYPE,$_POST["ID"]);
-					break;
-				case 7 : 
-					showLinkOnDevice(CONTACT_TYPE,$_POST["ID"]);
-					break;
-				case 10 :
-					showNotesForm($_POST['target'],CONTACT_TYPE,$_POST["ID"]);
-					break;
-				default :
-					if (!displayPluginAction(CONTACT_TYPE,$_POST["ID"],$_POST['glpi_tab'])){
-						showEnterpriseContact($_POST["ID"]);
-					}
-					break;
-			}
-	
+if (empty($_POST["id"])) {
+   $_POST["id"] = -1;
 }
-	ajaxFooter();
 
-?>
\ No newline at end of file
+$contact = new Contact();
+if ($_POST['id']>0 && $contact->getFromDB($_POST['id'])) {
+   switch($_REQUEST['glpi_tab']) {
+      case -1 :
+         $contact->showSuppliers();
+         Document::showAssociated($contact);
+         Link::showForItem('Contact',$_POST["id"]);
+         Plugin::displayAction($contact,$_REQUEST['glpi_tab']);
+         break;
+
+      case 5 :
+         Document::showAssociated($contact);
+         break;
+
+      case 7 :
+         Link::showForItem('Contact',$_POST["id"]);
+         break;
+
+      case 10 :
+         showNotesForm($_POST['target'],'Contact',$_POST["id"]);
+         break;
+
+      case 12 :
+         Log::showForItem($contact);
+         break;
+
+      default :
+         if (!Plugin::displayAction($contact,$_REQUEST['glpi_tab'])) {
+            $contact->showSuppliers();
+         }
+   }
+}
+
+ajaxFooter();
+
+?>
