@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contract.tabs.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: contract.tabs.php 10763 2010-02-24 18:46:11Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,50 +33,58 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-$NEEDED_ITEMS=array("contract","enterprise","computer","printer","monitor","peripheral","networking","software","document","link","phone","infocom","contact");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
-if(!isset($_POST["ID"])) {
-	exit();
+if (!isset($_POST["id"])) {
+   exit();
 }
 
-
-if(!isset($_POST["ID"])) $_POST["ID"] = -1;
+if (!isset($_POST["id"])) {
+   $_POST["id"] = -1;
+}
 
 $contract=new Contract();
 
-		if ($_POST['ID']>0){
-			switch($_POST['glpi_tab']){
-				case -1 :	
-					showEnterpriseContract($_POST["ID"]);
-					showDeviceContract($_POST["ID"]);
-					showDocumentAssociated(CONTRACT_TYPE,$_POST["ID"]);
-					showLinkOnDevice(CONTACT_TYPE,$_POST["ID"]);
-					displayPluginAction(CONTRACT_TYPE,$_POST["ID"],$_POST['glpi_tab']);
-					break;
-				case 2 :
-					showDeviceContract($_POST["ID"]);
-					break;
-				case 5 : 
-					showDocumentAssociated(CONTRACT_TYPE,$_POST["ID"]);
-					break;
-				case 7 : 
-					showLinkOnDevice(CONTRACT_TYPE,$_POST["ID"]);
-					break;
-				case 10 :
-					showNotesForm($_POST['target'],CONTRACT_TYPE,$_POST["ID"]);
-					break;
-				default :
-					if (!displayPluginAction(CONTRACT_TYPE,$_POST["ID"],$_POST['glpi_tab'])){
-						showEnterpriseContract($_POST["ID"]);
-					}
-					break;
-			}
-		}
-		
-	ajaxFooter();
+if ($_POST['id']>0  && $contract->can($_POST['id'],'r')) {
+   switch($_REQUEST['glpi_tab']) {
+      case -1 :
+         $contract->showSuppliers();
+         $contract->showItems();
+         Document::showAssociated($contract);
+         Link::showForItem('Contact',$_POST["id"]);
+         Plugin::displayAction($contract,$_REQUEST['glpi_tab']);
+         break;
+
+      case 2 :
+         $contract->showItems();
+         break;
+
+      case 5 :
+         Document::showAssociated($contract);
+         break;
+
+      case 7 :
+         Link::showForItem('Contract',$_POST["id"]);
+         break;
+
+      case 10 :
+         showNotesForm($_POST['target'],'Contract',$_POST["id"]);
+         break;
+
+      case 12 :
+         Log::showForItem($contract);
+         break;
+
+      default :
+         if (!Plugin::displayAction($contract,$_REQUEST['glpi_tab'])) {
+            $contract->showSuppliers();
+         }
+   }
+}
+
+ajaxFooter();
+
 ?>
