@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownConnect.php 11725 2010-06-15 18:27:56Z tsmr $
+ * @version $Id: dropdownConnect.php 13579 2011-01-11 12:18:27Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -75,10 +75,6 @@ if ($item->maybeTemplate()) {
    $where.=" AND `$table`.`is_template` = '0' ";
 }
 
-if (!empty($used)) {
-   $where.=" AND `$table`.`id` NOT IN ('".implode("','",$used)."')";
-}
-
 if (strlen($_POST['searchText'])>0 && $_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]) {
    $where.=" AND ( `$table`.`name` ".makeTextSearch($_POST['searchText']).
                  " OR `$table`.`otherserial` ".makeTextSearch($_POST['searchText']).
@@ -105,13 +101,18 @@ if ($_POST['searchText']==$CFG_GLPI["ajax_wildcard"]) {
    $LIMIT="";
 }
 
+$where_used = '';
+if (!empty($used)) {
+   $where_used = " AND `$table`.`id` NOT IN ('".implode("','",$used)."')";
+}
+
 if ($_POST["onlyglobal"] && $_POST["idtable"] != 'Computer') {
    $CONNECT_SEARCH=" WHERE `$table`.`is_global` = '1' ";
 } else {
    if ($_POST["idtable"] == 'Computer') {
       $CONNECT_SEARCH=" WHERE 1 ";
    } else {
-      $CONNECT_SEARCH=" WHERE (`glpi_computers_items`.`id` IS NULL
+      $CONNECT_SEARCH=" WHERE ((`glpi_computers_items`.`id` IS NULL $where_used)
                               OR `$table`.`is_global` = '1') ";
    }
 }
