@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleaction.php 10769 2010-02-25 16:55:55Z walid $
+ * @version $Id: ruleaction.php 13303 2010-12-14 13:15:14Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -56,15 +56,15 @@ if (isset($_POST["sub_type"]) && class_exists($_POST["sub_type"])) {
    $randaction=RuleAction::dropdownActions($_POST["sub_type"],"action_type",$_POST["field"]);
 
    echo "&nbsp;&nbsp;";
-   echo "<span id='action_type_span'>\n";
+   echo "<span id='action_type_span$randaction'>\n";
    echo "</span>\n";
 
    $paramsaction=array('action_type'=>'__VALUE__',
                        'field'=>$_POST["field"],
                        'sub_type'=>$_POST["sub_type"]);
-   ajaxUpdateItemOnSelectEvent("dropdown_action_type$randaction","action_type_span",
+   ajaxUpdateItemOnSelectEvent("dropdown_action_type$randaction","action_type_span$randaction",
                                $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$paramsaction,false);
-   ajaxUpdateItem("action_type_span",$CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$paramsaction,
+   ajaxUpdateItem("action_type_span$randaction",$CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$paramsaction,
                   false,"dropdown_action_type$randaction");
 }
 
