@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecriteriavalue.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: rulecriteriavalue.php 10769 2010-02-25 16:55:55Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -34,29 +34,25 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(strstr($_SERVER['PHP_SELF'],"rulecriteriavalue.php")){
-	define('GLPI_ROOT','..');
-	//$AJAX_INCLUDE=1;
-	$NEEDED_ITEMS = array("tracking");
-	include (GLPI_ROOT."/inc/includes.php");
-	header("Content-Type: text/html; charset=UTF-8");
-	header_nocache();
-};
+if (strstr($_SERVER['PHP_SELF'],"rulecriteriavalue.php")) {
+   define('GLPI_ROOT','..');
+   include (GLPI_ROOT."/inc/includes.php");
+   header("Content-Type: text/html; charset=UTF-8");
+   header_nocache();
+}
 
-if (!defined('GLPI_ROOT')){
-	die("Can not acces directly to this file");
+if (!defined('GLPI_ROOT')) {
+   die("Can not acces directly to this file");
 }
 
-include_once (GLPI_ROOT."/inc/rulesengine.function.php");
-	
 checkLoginUser();
-// Non define case
-if (isset($_POST["sub_type"])){
-	$rule=getRuleClass($_POST["sub_type"]);
-	$criterias=$rule->getCriterias();
-	$rule->displayCriteriaSelectPattern("pattern",$_POST["criteria"],$_POST['condition']);
-}
 
-	
+// Non define case
+if (isset($_POST["sub_type"])) {
+   $type = $_POST["sub_type"];
+   $rule = new $type();
+   $criterias=$rule->getCriterias();
+   $rule->displayCriteriaSelectPattern("pattern",$_POST["criteria"],$_POST['condition']);
+}
 
 ?>
