@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: updatecurrenttab.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: updatecurrenttab.php 10753 2010-02-24 08:55:22Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -32,6 +32,7 @@
 // Original Author of file: Julien Dombre
 // Purpose of file:
 // ----------------------------------------------------------------------
+
 define('GLPI_ROOT','..');
 include_once (GLPI_ROOT . "/config/based_config.php");
 include_once (GLPI_ROOT . "/inc/common.function.php");
@@ -42,8 +43,7 @@ header_nocache();
 setGlpiSessionPath();
 startGlpiSession();
 // Manage tabs
-if (isset($_REQUEST['glpi_tab'])) {
-	$_SESSION['glpi_tab']=$_REQUEST['glpi_tab'];
+if (isset($_REQUEST['glpi_tab']) && isset($_REQUEST['itemtype'])) {
+   setActiveTab($_REQUEST['itemtype'], $_REQUEST['glpi_tab']);
 }
-
-?>
+?>
\ No newline at end of file
