@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: define.php 13035 2010-11-12 13:13:49Z moyo $
+ * @version $Id: define.php 13571 2011-01-11 10:40:08Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -31,7 +31,7 @@
 
 
 // Current version of GLPI
-define("GLPI_VERSION","0.78.1");
+define("GLPI_VERSION","0.78.2");
 define("GLPI_DEMO_MODE","0");
 
 
@@ -57,7 +57,6 @@ $CFG_GLPI['languages'] =  //| NAME in native lang    |LANG FILE  |extjs| tinymce
             'lv_LV' => array('Latviešu',             'lv_LV.php','lv',    'lv','latvian'),
             'lt_LT' => array('Lietuvių',             'lt_LT.php','lt',    'lt','lithuanian'),
             'nl_NL' => array('Nederlands',           'nl_NL.php','nl',    'nl','dutch'),
-            'nl_BE' => array('Nederlands (Belgium)', 'nl_BE.php','nl',    'nl','dutch'),
             'no_NB' => array('Norsk (Bokmål)',       'no_NB.php','no_NB', 'nb','norwegian'),
             'no_NN' => array('Norsk (Nynorsk)',      'no_NN.php','no_NN', 'nn','norwegian'),
             'pl_PL' => array('Polski',               'pl_PL.php','pl',    'pl','polish'),
@@ -66,7 +65,7 @@ $CFG_GLPI['languages'] =  //| NAME in native lang    |LANG FILE  |extjs| tinymce
             'ro_RO' => array('Română',               'ro_RO.php','ro',    'en','romanian'),
             'ru_RU' => array('Pусский',              'ru_RU.php','ru',    'ru','russian'),
             'sk_SK' => array('Slovenčina',           'sk_SK.php','sk',    'sk','slovak'),
-            'sl_SL' => array('Slovenščina',          'sl_SI.php','sl',    'sl','slovenian slovene'),
+            'sl_SI' => array('Slovenščina',          'sl_SI.php','sl',    'sl','slovenian slovene'),
             'sv_SE' => array('Svenska',              'sv_SE.php','sv_SE', 'sv','swedish'),
             'tr_TR' => array('Türkçe',               'tr_TR.php','tr',    'tr','turkish'),
             'ua_UA' => array('Українська',           'ua_UA.php','ukr',   'en','ukrainian'),
@@ -265,8 +264,8 @@ $CFG_GLPI["notificationmethods_types"] = array('NotificationMail');
 $CFG_GLPI["union_search_type"] = array('ReservationItem'=>"reservation_types",
                                        'States'=>"state_types");
 
-$CFG_GLPI["systeminformations_type"] = array ('DBConnection','Plugin','AuthLDAP',
-                                              'MailCollector','OcsServer');
+$CFG_GLPI["systeminformations_types"] = array ('DBConnection','Plugin','AuthLDAP',
+                                               'MailCollector','OcsServer');
 
 // New config options which can be missing during migration
 $CFG_GLPI["number_format"]=0;
