@@ -1,8 +1,7 @@
 <?php
 
-
 /*
- * @version $Id: auth.others.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: auth.others.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -35,28 +34,21 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$NEEDED_ITEMS = array (
-	"setup",
-	"auth",
-	"ldap",
-	"user"
-);
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("config", "w");
+
 $config = new Config();
 
 //Update CAS configuration
 if (isset ($_POST["update"])) {
-	$config->update($_POST);
-	glpi_header($CFG_GLPI["root_doc"] . "/front/auth.others.php");
+   $config->update($_POST);
+   glpi_header($CFG_GLPI["root_doc"] . "/front/auth.others.php");
 }
 
-
-if (!isset($_GET["ID"])){
-	$_GET["ID"]="";	
+if (!isset($_GET["id"])) {
+   $_GET["id"]="";
 }
 
 commonHeader($LANG['title'][14], $_SERVER['PHP_SELF'],"config","extauth","others");
@@ -64,4 +56,5 @@ commonHeader($LANG['title'][14], $_SERVER['PHP_SELF'],"config","extauth","others
 showOtherAuthList($_SERVER['PHP_SELF']);
 
 commonFooter();
-?>
\ No newline at end of file
+
+?>
