@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: device.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: device.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,40 +33,19 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-$NEEDED_ITEMS=array("device","enterprise");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-
 checkRight("device","w");
 
 commonHeader($LANG['title'][30],$_SERVER['PHP_SELF'],"config","device");
+echo "<div align='center'>";
 
-if(!isset($_GET["device_type"])) $_GET["device_type"] = "0";
-if(!empty($_GET["device_type"])) {
-	titleDevices($_GET["device_type"]);
-}
-
-echo "<form method='get' action=\"".$CFG_GLPI["root_doc"]."/front/device.php\">";
-echo "<table class='tab_cadre' cellpadding='3'><tr><th colspan='2'>";
-echo $LANG['devices'][17].": </th></tr><tr class='tab_bg_1'><td><select name='device_type'>";
-
-$dp=getDictDeviceLabel();
-
-foreach ($dp as $key=>$val) {
-	$sel="";
-	if ($_GET["device_type"]==$key) $sel="selected";
-	echo "<option value='$key' $sel>".$val."</option>";	
-}
-echo "</select></td>";
-echo "<td><input type='submit' value=\"".$LANG['buttons'][2]."\" class='submit' ></td></tr>";
-echo "</table></form>";
-
-if(!empty($_GET["device_type"])) {
-	showDevicesList($_GET["device_type"],$_SERVER['PHP_SELF']);
-}
-
+$optgroup = Dropdown::getDeviceItemTypes();
+Dropdown::showItemTypeMenu($LANG['title'][30], $optgroup);
+Dropdown::showItemTypeList($optgroup);
 
+echo "</div>";
 commonFooter();
+
 ?>
