@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdown.common.form.php 12404 2010-09-14 07:13:08Z moyo $
+ * @version $Id: dropdown.common.form.php 13461 2010-12-24 10:20:18Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -75,7 +75,7 @@ if (isset($_POST["add"])) {
       $dropdown->refreshParentInfos();
 
       Event::log($_POST["id"], get_class($dropdown), 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
-      glpi_header($dropdown->getSearchURL());
+      $dropdown->redirectToList();
    }
 
 } else if (isset($_POST["replace"])) {
@@ -84,7 +84,7 @@ if (isset($_POST["add"])) {
    $dropdown->refreshParentInfos();
 
    Event::log($_POST["id"], get_class($dropdown), 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
-   glpi_header($dropdown->getSearchURL());
+   $dropdown->redirectToList();
 
 } else if (isset($_POST["update"])) {
    $dropdown->check($_POST["id"],'w');
