@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ocsng.sync.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: ocsng.sync.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,9 +33,6 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-$NEEDED_ITEMS=array("ocsng","rulesengine","rule.ocs","computer","device","printer","networking","peripheral","monitor","software","infocom","phone","tracking","enterprise","reservation","setup","registry","admininfo","group","rule.softwarecategories","rule.dictionnary.software","rule.dictionnary.dropdown");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
@@ -43,50 +40,48 @@ checkRight("ocsng","w");
 
 commonHeader($LANG['ocsng'][0],$_SERVER['PHP_SELF'],"utils","ocsng");
 
-if (isset($_SESSION["ocs_update"])){	
-	if ($count=count($_SESSION["ocs_update"])){
-		$percent=min(100,round(100*($_SESSION["ocs_update_count"]-$count)/$_SESSION["ocs_update_count"],0));
+if (isset($_SESSION["ocs_update"])) {
+   if ($count = count($_SESSION["ocs_update"])) {
+      $percent = min(100,round(100*($_SESSION["ocs_update_count"]-$count)
+                               /$_SESSION["ocs_update_count"],0));
 
-		displayProgressBar(400,$percent);
+      displayProgressBar(400,$percent);
 
-		$key=array_pop($_SESSION["ocs_update"]);
-		ocsUpdateComputer($key,$_SESSION["ocs_server_id"],2);
-		glpi_header($_SERVER['PHP_SELF']);
-	} else {
-		unset($_SESSION["ocs_update"]);
+      $key = array_pop($_SESSION["ocs_update"]);
+      OcsServer::updateComputer($key,$_SESSION["ocsservers_id"],2);
+      glpi_header($_SERVER['PHP_SELF']);
+   } else {
+      unset($_SESSION["ocs_update"]);
+      displayProgressBar(400,100);
 
-		displayProgressBar(400,100);
-
-		echo "<div align='center'><strong>".$LANG['ocsng'][8]."<br>";
-		echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a>";
-		echo "</strong></div>";
-	}
+      echo "<div class='center b'>".$LANG['ocsng'][8]."<br>";
+      echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a></div>";
+   }
 }
 
-
-if (!isset($_POST["update_ok"])){	
-	if (!isset($_GET['check'])) $_GET['check']='all';
-	if (!isset($_GET['start'])) $_GET['start']=0;
-
-	ocsManageDeleted($_SESSION["ocs_server_id"]);
-	ocsShowUpdateComputer($_SESSION["ocs_server_id"],$_GET['check'],$_GET['start']);
+if (!isset($_POST["update_ok"])) {
+   if (!isset($_GET['check'])) {
+      $_GET['check'] = 'all';
+   }
+   if (!isset($_GET['start'])) {
+      $_GET['start'] = 0;
+   }
+   OcsServer::manageDeleted($_SESSION["ocsservers_id"]);
+   OcsServer::showComputersToUpdate($_SESSION["ocsservers_id"],$_GET['check'],$_GET['start']);
 
 } else {
-	if (count($_POST['toupdate'])>0){		
-		$_SESSION["ocs_update_count"]=0;
-		foreach ($_POST['toupdate'] as $key => $val){
-			if ($val=="on")	{
-				$_SESSION["ocs_update"][]=$key;
-				$_SESSION["ocs_update_count"]++;
-			}
-
-		}
-	}
-
-	glpi_header($_SERVER['PHP_SELF']);
+   if (count($_POST['toupdate']) >0) {
+      $_SESSION["ocs_update_count"] = 0;
+      foreach ($_POST['toupdate'] as $key => $val) {
+         if ($val == "on") {
+            $_SESSION["ocs_update"][] = $key;
+            $_SESSION["ocs_update_count"]++;
+         }
+      }
+   }
+   glpi_header($_SERVER['PHP_SELF']);
 }
 
-
 commonFooter();
 
-?>
+?>
\ No newline at end of file
