@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: profile.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -34,9 +34,6 @@
 // ----------------------------------------------------------------------
 
 
-
-$NEEDED_ITEMS=array("profile","search");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
@@ -44,11 +41,7 @@ checkRight("profile","r");
 
 commonHeader($LANG['Menu'][35],$_SERVER['PHP_SELF'],"admin","profile");
 
-manageGetValuesInSearch(PROFILE_TYPE);
-
-searchForm(PROFILE_TYPE,$_GET);
-
-showList(PROFILE_TYPE,$_GET);
+Search::show('Profile');
 
 commonFooter();
 
