@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.reservation.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: report.reservation.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,9 +33,6 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-$NEEDED_ITEMS=array("reservation","computer","printer","monitor","peripheral","networking","software","phone");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
@@ -43,19 +40,25 @@ checkRight("reports","r");
 
 commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
-if (!isset($_GET["ID"])) $_GET["ID"]=0;
+if (!isset($_GET["id"])) {
+   $_GET["id"] = 0;
+}
 
-echo "<div align='center'><form method=\"get\" name=\"form\" action=\"report.reservation.php\">";
+echo "<form method='get' name='form' action='report.reservation.php'>";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
-echo "<td rowspan='2' align='center'>";
-dropdownAllUsers("ID",$_GET["ID"],"reservation_helpdesk");
+echo "<td rowspan='2' class='center'>";
+User::dropdown(array('name'   => 'id',
+                     'value'  => $_GET["id"],
+                     'right'  => 'reservation_helpdesk'));
+
 echo "</td>";
-echo "<td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG['buttons'][7] ."\" /></td></tr>";
-echo "</table></form></div>";
-
-if ($_GET["ID"]>0)
-showUserReservations($_SERVER['PHP_SELF'],$_GET["ID"]);
+echo "<td rowspan='2' class='center'><input type='submit' class='button' name='submit' value='".
+      $LANG['buttons'][7] ."'></td></tr>";
+echo "</table></form>";
 
+if ($_GET["id"] > 0) {
+   Reservation::showForUser($_GET["id"]);
+}
 commonFooter();
 
 ?>
