@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.generic.form.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: rule.generic.form.php 10700 2010-02-22 14:16:17Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,19 +33,15 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-$NEEDED_ITEMS=array("entity","rulesengine","rule.right","rule.ocs","rule.tracking","rule.softwarecategories");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-if (isset($_GET["ID"]))
-{
-	$generic_rule = new Rule;
-	$generic_rule->getFromDB($_GET["ID"]);
-	checkRight($generic_rule->right,"r");
-	
-	$rulecollection=getRuleCollectionClass($generic_rule->fields["sub_type"]);
-	include (GLPI_ROOT . "/front/rule.common.form.php");
+if (isset($_GET["id"])) {
+   $generic_rule = new Rule;
+   $generic_rule->getFromDB($_GET["id"]);
+   checkRight($generic_rule->right,"r");
+
+   $rulecollection = RuleCollection::getClassByType($generic_rule->fields["sub_type"]);
+   include (GLPI_ROOT . "/front/rule.common.form.php");
 }
 ?>
