@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: state.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: state.php 10411 2010-02-09 07:58:26Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -29,32 +29,14 @@
  */
 
 // ----------------------------------------------------------------------
-// Original Author of file:
+// Original Author of file: Remi collet
 // Purpose of file:
 // ----------------------------------------------------------------------
 
 
-
-$NEEDED_ITEMS=array("search","state");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-if (!isset($_GET["synthese"])) $_GET["synthese"] = "no";
-
-checkCentralAccess();
-
-commonHeader($LANG['title'][9],$_SERVER['PHP_SELF'],"inventory","state");
-
-if ($_GET["synthese"]=="yes"){
-	showStateSummary($_SERVER['PHP_SELF']);
-} else {
-	manageGetValuesInSearch(STATE_TYPE);
-
-	searchForm(STATE_TYPE,$_GET);
-
-	showList(STATE_TYPE,$_GET);
-}
-
-commonFooter();
+$dropdown = new State();
+include (GLPI_ROOT . "/front/dropdown.common.php");
 ?>
