@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: user.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: user.php 10661 2010-02-19 18:11:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -33,32 +33,18 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
-
-
-$NEEDED_ITEMS=array("search","user");
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("user","r");
 
-commonHeader($LANG['Menu'][14],$_SERVER['PHP_SELF'],"admin","user");	
+commonHeader($LANG['Menu'][14],'',"admin","user");
 
 $user=new User();
 $user->title();
 
-
-
-manageGetValuesInSearch(USER_TYPE);
-
-searchForm(USER_TYPE,$_GET);
-
-showList(USER_TYPE,$_GET);
+Search::show('User');
 
 commonFooter();
 
-
-
-
 ?>
