@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: common.function.php 12871 2010-10-26 06:28:43Z moyo $
+ * @version $Id: common.function.php 13333 2010-12-16 13:58:25Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -211,8 +211,8 @@ function logInFile($name,$text,$force=false) {
    global $CFG_GLPI;
 
    if (isset($CFG_GLPI["use_log_in_files"]) && $CFG_GLPI["use_log_in_files"]||$force) {
-      error_log(convDateTime(date("Y-m-d H:i:s"))." [".getLoginUserID()."]\n".$text,
-                3,GLPI_LOG_DIR."/".$name.".log");
+      error_log(convDateTime(date("Y-m-d H:i:s"))." [".getLoginUserID().'@'.php_uname('n')."]\n".$text,
+                3, GLPI_LOG_DIR."/".$name.".log");
    }
 }
 
@@ -983,7 +983,8 @@ function html_clean($value) {
    // nettoyer l'apostrophe curly qui pose probleme a certains rss-readers, lecteurs de mail...
    $value = str_replace("&#8217;","'",$value);
 
-   $value = preg_replace("/ +/u", " ", $value);
+// Problem with this regex : may crash
+//   $value = preg_replace("/ +/u", " ", $value);
    $value = preg_replace("/\n{2,}/", "\n\n", $value,-1);
    return trim($value);
 }
@@ -1295,10 +1296,11 @@ function get_hour_from_sql($time) {
  *  Optimize sql table
  *
  * @param $progress_fct function to call to display progress message
+ * @param $cron to know if optimize must be done
  *
  * @return number of tables
  */
-function optimize_tables ($progress_fct=NULL){
+function optimize_tables ($progress_fct=NULL, $cron=false){
    global $DB;
 
    if (function_exists($progress_fct)) {
@@ -1308,12 +1310,17 @@ function optimize_tables ($progress_fct=NULL){
    $nb=0;
    while ($line = $DB->fetch_array($result)) {
       $table = $line[0];
-      if (function_exists($progress_fct)) {
-         $progress_fct("optimize", $table);
+
+   // For big database to reduce delay of migration
+      if ($cron || countElementsInTable($table) < 15000000) {
+
+         if (function_exists($progress_fct)) {
+            $progress_fct("optimize", $table);
+         }
+         $query = "OPTIMIZE TABLE `".$table."` ;";
+         $DB->query($query);
+         $nb++;
       }
-      $query = "OPTIMIZE TABLE `".$table."` ;";
-      $DB->query($query);
-      $nb++;
    }
    $DB->free_result($result);
 
