@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commondbtm.class.php 13008 2010-11-09 21:47:32Z moyo $
+ * @version $Id: commondbtm.class.php 13661 2011-01-18 11:06:56Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -583,7 +583,6 @@ class CommonDBTM extends CommonGLPI {
          if (isset($table_fields['date_mod'])) {
             $this->fields['date_mod']=$_SESSION["glpi_currenttime"];
          }
-
          if ($this->addToDB()) {
             $this->addMessageOnAddAction();
             $this->post_addItem();
@@ -663,15 +662,13 @@ class CommonDBTM extends CommonGLPI {
 
       if ($addMessAfterRedirect) {
 
-         // Do not display quotes
-         if (isset($this->fields['name'])) {
-            $this->fields['name']=stripslashes($this->fields['name']);
-         } else {
+         if (($name=$this->getName()) == NOT_AVAILABLE) {
             $this->fields['name']=$this->getTypeName()." : ".$LANG['common'][2]." ".$this->fields['id'];
-         }
+         } 
+         $display=(isset($this->input['_no_message_link'])?$this->getNameID():$this->getLink());
 
-         addMessageAfterRedirect($LANG['common'][70] . "&nbsp;: " .
-                  (isset($this->input['_no_message_link'])?$this->getNameID():$this->getLink()));
+         // Do not display quotes
+         addMessageAfterRedirect($LANG['common'][70]."&nbsp;: ".stripslashes($display));
       }
    }
 
@@ -1346,6 +1343,7 @@ class CommonDBTM extends CommonGLPI {
    *     - withtemplate : 1 for newtemplate, 2 for newobject from template
    *     - colspan for each column (default 2)
    *     - candel : set to false to hide "delete" button
+   *     - canedit : set to false to hide all buttons
     *
     */
    function showFormButtons ($options=array()) {
@@ -1360,14 +1358,19 @@ class CommonDBTM extends CommonGLPI {
       $params['colspan'] = 2;
       $params['withtemplate'] = '';
       $params['candel'] = true;
+      $params['canedit'] = true;
 
       if (is_array($options) && count($options)) {
          foreach ($options as $key => $val) {
             $params[$key]=$val;
          }
       }
-      if (!$this->can($ID,'w')) {
+      if (!$params['canedit'] || !$this->can($ID,'w') ) {
          echo "</table></div>";
+         // Form Header always open form
+         if (!$params['canedit']) {
+            echo "</form>";
+         }
          return false;
       }
       echo "<tr>";
@@ -1451,7 +1454,9 @@ class CommonDBTM extends CommonGLPI {
       // Template case : clean entities data
       if ($params['withtemplate'] == 2 && $this->isEntityAssign()) {
          $this->fields['entities_id'] = $_SESSION['glpiactive_entity'];
-         $this->fields["is_recursive"] = 0;
+         if ($this->maybeRecursive()) {
+            $this->fields["is_recursive"] = 0;
+         }
       }
 
       if ($this->can($ID,'w')) {
@@ -1472,7 +1477,8 @@ class CommonDBTM extends CommonGLPI {
                   $entity = $this->fields['entities_id'];
                }
                echo "<input type='hidden' name='entities_id' value='$entity'>";
-            } else {
+
+            } else if ($this->getType() != 'User') {
                echo "<input type='hidden' name='entities_id' value='0'>";
 
             }
@@ -1747,6 +1753,7 @@ class CommonDBTM extends CommonGLPI {
       if (!array_key_exists('id',$this->fields)) {
          $this->getEmpty();
       }
+
       return array_key_exists('is_recursive', $this->fields);
    }
 
@@ -2031,13 +2038,13 @@ class CommonDBTM extends CommonGLPI {
     * $crit array of criteria (ex array('is_active'=>'1'))
     *
     **/
-   function deleteByCriteria($crit=array()) {
+   function deleteByCriteria($crit=array(),$force=0) {
       global $DB;
 
       if (is_array($crit) && count($crit)>0) {
          $crit['FIELDS'] = 'id';
          foreach ($DB->request($this->getTable(), $crit) as $row) {
-            $this->delete($row);
+            $this->delete($row,$force);
          }
       }
    }
