@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commontreedropdown.class.php 11788 2010-06-23 13:01:18Z moyo $
+ * @version $Id: commontreedropdown.class.php 13156 2010-11-26 13:50:47Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -333,7 +333,21 @@ abstract class CommonTreeDropdown extends CommonDropdown {
    function getID (&$input) {
       global $DB;
 
-      if (!empty($input["name"])) {
+      if (isset($input['completename']) && !empty($input['completename'])) {
+         $query = "SELECT `id`
+                   FROM `".$this->getTable()."`
+                   WHERE `completename` = '".$input['completename']."'";
+         if ($this->isEntityAssign()) {
+            $query .= getEntitiesRestrictRequest(' AND ',$this->getTable(),'',
+                                                 $input['entities_id'],$this->maybeRecursive());
+         }
+         // Check twin :
+         if ($result_twin = $DB->query($query) ) {
+            if ($DB->numrows($result_twin) > 0) {
+               return $DB->result($result_twin,0,"id");
+            }
+         }
+      } else if (isset($input['name']) && !empty($input['name'])) {
          $fk = $this->getForeignKeyField();
          $query = "SELECT `id`
                    FROM `".$this->getTable()."`
