@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_device.class.php 12090 2010-08-10 09:46:19Z yllen $
+ * @version $Id: computer_device.class.php 13564 2011-01-11 08:32:53Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -187,6 +187,11 @@ class Computer_Device extends CommonDBTM {
       echo "<tr><th colspan='63'>".$LANG['title'][30]."</th></tr>";
       $nb = 0;
 
+      $specificity_units = array ('DeviceProcessor' => $LANG['setup'][35],
+                                 'DeviceMemory' => $LANG['common'][82],
+                                 'DeviceHardDrive' => $LANG['common'][82],
+                                 'DeviceGraphicCard' => $LANG['common'][82]);
+
       foreach ($devtypes as $itemtype) {
          initNavigateListItems($itemtype, $computer->getTypeName()." = ".$computer->getName());
 
@@ -207,6 +212,7 @@ class Computer_Device extends CommonDBTM {
                   GROUP BY `$fk` $specif_text";
 
          $prev = '';
+
          foreach($DB->request($query) as $data) {
             addToNavigateListItems($itemtype, $data[$fk]);
 
@@ -233,10 +239,19 @@ class Computer_Device extends CommonDBTM {
                         // Specificity
                         echo "<td class='right' colspan='$colspan'>".$spec['label'][$i]."&nbsp;: ";
                         echo "<input type='text' name='value_".$itemtype."_".$data['id']."' value='";
-                        echo $data['specificity']."' size='".$spec['size']."' ></td>";
+                        echo $data['specificity']."' size='".$spec['size']."' >";
+                        if (isset($specificity_units[$device->getType()])) {
+                           echo '&nbsp;'.$specificity_units[$device->getType()];
+                        }
+                        echo "</td>";
                      } else {
                         echo "<td colspan='$colspan'>".$spec['label'][$i]."&nbsp;: ";
-                        echo $data['specificity']."</td>";
+                        echo $data['specificity'];
+                        if (isset($specificity_units[$device->getType()])) {
+                           echo '&nbsp;'.$specificity_units[$device->getType()];
+                        }
+
+                        echo "</td>";
                      }
                   }
                } else {
