@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dbmysql.class.php 12383 2010-09-10 08:47:07Z moyo $
+ * @version $Id: dbmysql.class.php 13658 2011-01-18 10:58:45Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -52,7 +52,8 @@ class DBocs extends DBmysql {
          $this->dbuser = $data["ocs_db_user"];
          $this->dbpassword = rawurldecode($data["ocs_db_passwd"]);
          $this->dbdefault = $data["ocs_db_name"];
-         $this->dbenc="latin1";
+         $this->dbenc = $data["ocs_db_utf8"] ? "utf8" : "latin1";
+
          parent::__construct();
       }
    }
