@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdown.class.php 13006 2010-11-09 21:43:00Z moyo $
+ * @version $Id: dropdown.class.php 13199 2010-12-02 07:57:05Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -1138,12 +1138,13 @@ class Dropdown {
 
          $isadmin=$item->canUpdate();
 
+
          echo "<select name='massiveaction' id='massiveaction'>";
          echo "<option value='-1' selected>".DROPDOWN_EMPTY_VALUE."</option>";
          if (!in_array($itemtype,$CFG_GLPI["massiveaction_noupdate_types"])
-            && ($isadmin ||(in_array($itemtype,$CFG_GLPI["infocom_types"])&& $infocom->canUpdate())
-                        || ($itemtype == 'Ticket' && haveRight('update_ticket',1)))) {
-
+            && (($isadmin && $itemtype != 'Ticket')
+                  ||(in_array($itemtype,$CFG_GLPI["infocom_types"])&& $infocom->canUpdate())
+                  || ($itemtype == 'Ticket' && haveRight('update_ticket',1)))) {
             echo "<option value='update'>".$LANG['buttons'][14]."</option>";
          }
 
@@ -1269,8 +1270,7 @@ class Dropdown {
                   break;
 
                case 'TicketValidation' :
-                  $tmp = new TicketValidation();
-                  if ($tmp->canUpdate()) {
+                  if (haveRight('create_validation', 1)) {
                      echo "<option value='validate_ticket'>".$LANG['validation'][0]."</option>";
                   }
                   break;
