@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: infocom.class.php 12250 2010-08-31 14:01:52Z moyo $
+ * @version $Id: infocom.class.php 13145 2010-11-24 12:37:32Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -914,8 +914,8 @@ class Infocom extends CommonDBTM {
       $tab[10]['datatype']  = 'text';
 
       $tab[11]['table']     = $this->getTable();
-      $tab[11]['field']     = 'delivry_number';
-      $tab[11]['linkfield'] = 'delivry_number';
+      $tab[11]['field']     = 'delivery_number';
+      $tab[11]['linkfield'] = 'delivery_number';
       $tab[11]['name']      = $LANG["financial"][19];
       $tab[11]['datatype']  = 'text';
 
