@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailcollector.class.php 12930 2010-10-29 09:21:23Z moyo $
+ * @version $Id: mailcollector.class.php 13613 2011-01-12 12:51:05Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -348,10 +348,9 @@ class MailCollector  extends CommonDBTM {
             $error = 0;
             $refused = 0;
 
-            for($i=1 ; $i<=$tot && $this->fetch_emails<=$this->maxfetch_emails ; $i++) {
+            for($i=1 ; $i<=$tot && $this->fetch_emails<$this->maxfetch_emails ; $i++) {
                $tkt = $this->buildTicket($i, array('mailgates_id' => $mailgateID,
                                                    'play_rules'   => true));
-
                //Indicates that the mail must be deleted from the mailbox
                $delete_mail = false;
 
@@ -364,7 +363,15 @@ class MailCollector  extends CommonDBTM {
                    || isset($tkt['_refuse_email_no_response'])
                    || isset($tkt['_refuse_email_with_response'])) {
 
-                  if (isset($tkt['entities_id']) || isset($tkt['tickets_id'])) {
+                  if (isset($tkt['_refuse_email_with_response'])) {
+                     $this->sendMailRefusedResponse($tkt['_head']['from'], $tkt['name']);
+                     $delete_mail = true;
+                     $refused++;
+
+                  } else if (isset($tkt['_refuse_email_no_response'])) {
+                     $delete_mail = true;
+                     $refused++;
+                  } else if (isset($tkt['entities_id']) || isset($tkt['tickets_id'])) {
                      $tkt['_mailgate'] = $mailgateID;
                      $result = imap_fetchheader($this->marubox, $i);
 
@@ -393,12 +400,11 @@ class MailCollector  extends CommonDBTM {
                      }
 
                   } else {
-                     if (isset($tkt['_refuse_email_with_response'])) {
-                        $this->sendMailRefusedResponse($tkt['user_email'], $tkt['name']);
-                     }
+                     // Case never raise
                      $delete_mail = true;
                      $refused++;
                   }
+
                   //Delete Mail from Mail box if ticket is added successfully
                   if ($delete_mail) {
                      $this->deleteMails($i);
@@ -531,6 +537,7 @@ class MailCollector  extends CommonDBTM {
          // Check if ticket  exists and users_id exists in GLPI
          /// TODO check if users_id have right to add a followup to the ticket
          if ($job->getFromDB($tkt['tickets_id'])
+             && $job->fields['status'] != 'closed'
              && ($tkt['users_id'] > 0 || !strcasecmp($job->fields['user_email'], $head['from']))) {
 
             $content = explode("\n", $tkt['content']);
@@ -555,14 +562,15 @@ class MailCollector  extends CommonDBTM {
                $tkt['content'] .= $content[$ID]."\n";
             }
 
-         // Do not play rules for followups
-         $play_rules = false;
+         // Do not play rules for followups : WRONG : play rules only for refuse options
+//          $play_rules = false;
 
          } else {
             unset($tkt['tickets_id']);
          }
       }
 
+      $tkt['name'] = $this->textCleaner($head['subject']);
       if (! isset($tkt['tickets_id'])) {
          // Mail followup
          $tkt['user_email'] = $head['from'];
@@ -570,7 +578,6 @@ class MailCollector  extends CommonDBTM {
          // Which entity ?
          //$tkt['entities_id']=$this->fields['entities_id'];
          //$tkt['Subject']= $head['subject'];   // not use for the moment
-         $tkt['name'] = $this->textCleaner($head['subject']);
          // Medium
          $tkt['urgency'] = "3";
          // No hardware associated
@@ -591,12 +598,23 @@ class MailCollector  extends CommonDBTM {
          $rulecollection = new RuleMailCollectorCollection();
          $output = $rulecollection->processAllRules(array(), array(), $rule_options);
 
-         foreach ($output as $key => $value) {
-            $tkt[$key] = $value;
+         // New ticket : compute all
+         if (! isset($tkt['tickets_id'])) {
+            foreach ($output as $key => $value) {
+               $tkt[$key] = $value;
+            }
+         } else { // Followup only copy refuse data
+            $tobecopied = array('_refuse_email_no_response', '_refuse_email_with_response');
+            foreach ($tobecopied as $val) {
+               if (isset($output[$val])) {
+                  $tkt[$val] = $output[$val];
+               }
+            }
          }
       }
 
       $tkt = addslashes_deep($tkt);
+
       return $tkt;
    }
 
@@ -700,10 +718,19 @@ class MailCollector  extends CommonDBTM {
       if (is_array($header) && count($header)) {
          foreach($header as $line) {
             // is line with additional header?
-            if (preg_match("/^X-/i", $line)) {
+            if (preg_match("/^X-/i", $line)
+               || preg_match("/^Auto-Submitted/i", $line)
+               || preg_match("/^Received/i", $line)) {
                // separate name and value
                if (preg_match("/^([^:]*): (.*)/i", $line, $arg)) {
-                  $head[$arg[1]] = $arg[2];
+                  $key = utf8_strtolower($arg[1]);
+                  if (!isset($head[$key])) {
+                     $head[$key] = '';
+                  } else {
+                     $head[$key] .= "\n";
+                  }
+
+                  $head[$key] .= trim($arg[2]);
                }
             }
          }
@@ -1155,7 +1182,8 @@ class MailCollector  extends CommonDBTM {
    function sendMailRefusedResponse($to='', $subject='') {
       global $CFG_GLPI, $LANG;
 
-      $mmail = new NotificationMail;
+      $mmail = new NotificationMail();
+      $mmail->AddCustomHeader("Auto-Submitted: auto-replied");
       $mmail->From = $CFG_GLPI["admin_email"];
       $mmail->FromName = "GLPI";
       $mmail->AddAddress($to);
