@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtargetticket.class.php 12989 2010-11-08 14:18:46Z remi $
+ * @version $Id: notificationtargetticket.class.php 13245 2010-12-07 14:32:50Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -234,7 +234,7 @@ class NotificationTargetTicket extends NotificationTarget {
 
 
    function getTicketOldAssignTechnicianAddress () {
-      return $this->getUserByField ("_old_assign");
+      return $this->getUserByOldValue ("users_id_assign");
    }
 
 
@@ -638,7 +638,7 @@ class NotificationTargetTicket extends NotificationTarget {
             $this->datas['##ticket.assigntogroup##'] = Dropdown::getDropdownName('glpi_groups',
                                                          $this->obj->getField('groups_id_assign'));
          } else {
-            $this->datas['##ticket.group##'] = '';
+            $this->datas['##ticket.assigntogroup##'] = '';
          }
 
          //Tags associated with the object linked to the ticket
@@ -806,6 +806,7 @@ class NotificationTargetTicket extends NotificationTarget {
             $tmp['##validation.submissiondate##']    = convDateTime($validation['submission_date']);
             $tmp['##validation.commentsubmission##'] = $validation['comment_submission'];
             $tmp['##validation.validationdate##']    = convDateTime($validation['validation_date']);
+            $tmp['##validation.validator##']         =  html_clean(getUserName($validation['users_id_validate']));
             $tmp['##validation.commentvalidation##'] = $validation['comment_validation'];
             $this->datas['validations'][] = $tmp;
          }
@@ -874,11 +875,17 @@ class NotificationTargetTicket extends NotificationTarget {
                $tmp['##ticket.assigntouser##'] = '';
             }
 
+            if ($ticket['groups_id']) {
+               $tmp['##ticket.group##'] = Dropdown::getDropdownName('glpi_groups', $ticket['groups_id']);
+            } else {
+               $tmp['##ticket.group##'] = '';
+            }
+
             if ($ticket['groups_id_assign']) {
                $tmp['##ticket.assigntogroup##'] = Dropdown::getDropdownName('glpi_groups',
                                                             $ticket['groups_id_assign']);
             } else {
-               $tmp['##ticket.group##'] = '';
+               $tmp['##ticket.assigntogroup##'] = '';
             }
 
             if ($ticket['suppliers_id_assign']) {
@@ -1004,6 +1011,7 @@ class NotificationTargetTicket extends NotificationTarget {
                    'validation.status'            => $LANG['joblist'][0],
                    'validation.submissiondate'    => $LANG['validation'][3],
                    'validation.commentsubmission' => $LANG['validation'][5],
+                   'validation.validator'         => $LANG['validation'][21],
                    'validation.validationdate'    => $LANG['validation'][4],
                    'validation.commentvalidation' => $LANG['validation'][6]);
 
