@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.class.php 12376 2010-09-09 19:56:44Z moyo $
+ * @version $Id: profile.class.php 13229 2010-12-07 10:45:33Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -171,7 +171,7 @@ class Profile extends CommonDBTM {
       // decode array
       if (isset($this->fields["helpdesk_item_type"])
             && !is_array($this->fields["helpdesk_item_type"])) {
-         $this->fields["helpdesk_item_type"]=importArrayFromDB($this->fields["helpdesk_item_type"],true);
+         $this->fields["helpdesk_item_type"]=importArrayFromDB($this->fields["helpdesk_item_type"]);
       }
       // Empty/NULL case
       if (!isset($this->fields["helpdesk_item_type"])
@@ -181,8 +181,13 @@ class Profile extends CommonDBTM {
       // Decode status array
       if (isset($this->fields["helpdesk_status"])
             && !is_array($this->fields["helpdesk_status"])) {
-         $this->fields["helpdesk_status"]=importArrayFromDB($this->fields["helpdesk_status"],true);
+         $this->fields["helpdesk_status"]=importArrayFromDB($this->fields["helpdesk_status"]);
+         // Need to be an array not a null value
+         if (is_null($this->fields["helpdesk_status"])) {
+            $this->fields["helpdesk_status"]=array();
+         }
       }
+
    }
 
    /**
