@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecollection.class.php 12832 2010-10-21 11:58:24Z remi $
+ * @version $Id: rulecollection.class.php 13532 2011-01-07 11:03:31Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -311,14 +311,14 @@ class RuleCollection extends CommonDBTM {
       $canedit = (haveRight($this->right, "w") && !$display_entities);
 
       $nb = $this->getCollectionSize($p['inherited']);
-      $p['start'] = (isset($_GET["start"]) ? $_GET["start"] : 0);
+      $p['start'] = (isset($options["start"]) ? $options["start"] : 0);
       if ($p['start'] >= $nb) {
          $p['start'] = 0;
       }
       $p['limit'] = $_SESSION['glpilist_limit'];
       $this->getCollectionPart($p);
 
-      printPager($p['start'],$nb,$target,"");
+      printAjaxPager('', $p['start'],$nb);
 
       echo "<br><form name='ruleactions_form' id='ruleactions_form' method='post'
              action=\"".$target."\">";
