@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ticketfollowup.class.php 11778 2010-06-23 09:22:03Z moyo $
+ * @version $Id: ticketfollowup.class.php 13632 2011-01-17 08:45:46Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -195,7 +195,6 @@ class TicketFollowup  extends CommonDBTM {
 //      $input["_isadmin"] = haveRight("global_add_followups","1");
       $input["_job"] = new Ticket;
 
-      // check rights made in front like all objects
       if (!$input["_job"]->getFromDB($input["tickets_id"])) {
          return false;
       }
@@ -250,6 +249,10 @@ class TicketFollowup  extends CommonDBTM {
 
       $donotif = $CFG_GLPI["use_mailing"];
 
+      if (isset($this->input["_no_notif"]) && $this->input["_no_notif"]) {
+         $donotif = false;
+      }
+
       $this->input["_job"]->updateDateMod($this->input["tickets_id"]);
 
       if (isset($this->input["_close"])
@@ -665,7 +668,7 @@ class TicketFollowup  extends CommonDBTM {
          echo "<tr><th colspan='4'>". $LANG['job'][51]."</th></tr>";
 
          echo "<tr class='tab_bg_1'>";
-         echo "<td class='middle right' colspan='2'>".$LANG['common'][25]."&nbsp;:</td>";
+         echo "<td colspan='2'>".$LANG['common'][25]."&nbsp;:<br>(".$LANG['validation'][16].")</td>";
          echo "<td class='center middle' colspan='2'><textarea name='content' cols='70' rows='6'>";
          echo "</textarea>";
          echo "<input type='hidden' name='tickets_id' value='".$ticket->getField('id')."'>";
@@ -683,6 +686,44 @@ class TicketFollowup  extends CommonDBTM {
       }
       return true;
    }
+
+   function getSearchOptions() {
+      global $LANG;
+
+      $tab = array();
+      $tab['common'] = $LANG['job'][9];
+
+      $tab[1]['table']        = 'glpi_ticketfollowups';
+      $tab[1]['field']        = 'content';
+      $tab[1]['linkfield']    = '';
+      $tab[1]['name']         = $LANG['job'][9]." - ".$LANG['joblist'][6];
+
+      $tab[2]['table']        = 'glpi_requesttypes';
+      $tab[2]['field']        = 'name';
+      $tab[2]['linkfield']    = 'requesttypes_id';
+      $tab[2]['name']         = $LANG['job'][9]." - ".$LANG['job'][44];
+      $tab[2]['forcegroupby'] = true;
+
+      $tab[3]['table']        = 'glpi_ticketfollowups';
+      $tab[3]['field']        = 'date';
+      $tab[3]['linkfield']    = '';
+      $tab[3]['name']         = $LANG['common'][26];
+      $tab[3]['datatype']     = 'datetime';
+
+      $tab[4]['table']        = 'glpi_ticketfollowups';
+      $tab[4]['field']        = 'is_private';
+      $tab[4]['linkfield']    = '';
+      $tab[4]['name']         = $LANG['job'][9]. " ".$LANG['common'][77];
+      $tab[4]['datatype']     = 'bool';
+
+      $tab[5]['table']        = 'glpi_users';
+      $tab[5]['field']        = 'name';
+      $tab[5]['linkfield']    = 'users_id';
+      $tab[5]['name']         = $LANG['common'][34];
+
+      return $tab;
+   }
+
 }
 
 
