@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ticketplanning.class.php 12345 2010-09-09 07:10:58Z yllen $
+ * @version $Id: ticketplanning.class.php 13246 2010-12-07 14:51:37Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -416,7 +416,8 @@ class TicketPlanning extends CommonDBTM {
          for ($i=0 ; $data=$DB->fetch_array($result) ; $i++) {
             if ($fup->getFromDB($data["tickettasks_id"])) {
                if ($job->getFromDBwithData($fup->fields["tickets_id"],0)) {
-                  if (haveAccessToEntity($job->fields["entities_id"])) {
+                     // Do not check entity here because webcal used non authenticated access
+//                   if (haveAccessToEntity($job->fields["entities_id"])) {
                      $interv[$data["begin"]."$$$".$i]["tickettasks_id"]=$data["tickettasks_id"];
                      $interv[$data["begin"]."$$$".$i]["state"]=$data["state"];
                      $interv[$data["begin"]."$$$".$i]["tickets_id"]=$fup->fields["tickets_id"];
@@ -438,11 +439,12 @@ class TicketPlanning extends CommonDBTM {
                      $interv[$data["begin"]."$$$".$i]["device"]=($job->hardwaredatas ?$job->hardwaredatas->getName():'');
                      $interv[$data["begin"]."$$$".$i]["status"]=$job->fields["status"];
                      $interv[$data["begin"]."$$$".$i]["priority"]=$job->fields["priority"];
-                  }
+//                   }
                }
             }
          }
       }
+
       return $interv;
    }
 
