@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: user.class.php 12995 2010-11-09 09:13:49Z moyo $
+ * @version $Id: user.class.php 13541 2011-01-07 14:46:55Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -107,19 +107,6 @@ class User extends CommonDBTM {
       return false;
    }
 
-   /**
-    * Constructor
-   **/
-   function __construct() {
-      global $CFG_GLPI;
-
-      if (isset ($CFG_GLPI["language"])) {
-         $this->fields['language'] = $CFG_GLPI["language"];
-      } else {
-         $this->fields['language'] = "en_GB";
-      }
-   }
-
    /**
    * Compute preferences for the current user mixing config and user data
    **/
@@ -162,7 +149,15 @@ class User extends CommonDBTM {
    }
 
    function post_getEmpty () {
+      global $CFG_GLPI;
+
       $this->fields["is_active"] = 1;
+
+      if (isset ($CFG_GLPI["language"])) {
+         $this->fields['language'] = $CFG_GLPI["language"];
+      } else {
+         $this->fields['language'] = "en_GB";
+      }
    }
 
    function pre_deleteItem() {
@@ -593,7 +588,9 @@ class User extends CommonDBTM {
    function syncLdapGroups() {
       global $DB;
 
+      // input["_groups"] not set when update from user.form or preference
       if (isset($this->fields["authtype"])
+          && isset($this->input["_groups"])
           && ($this->fields["authtype"] == Auth::LDAP
               || Auth::isAlternateAuthWithLdap($this->fields['authtype']))) {
 
@@ -601,9 +598,6 @@ class User extends CommonDBTM {
             $authtype = Auth::getMethodsByID($this->fields["authtype"], $this->fields["auths_id"]);
 
             if (count($authtype)) {
-               if (!isset($this->input["_groups"])) {
-                  $this->input["_groups"] = array();
-               }
                // Clean groups
                $this->input["_groups"] = array_unique ($this->input["_groups"]);
 
@@ -866,6 +860,9 @@ class User extends CommonDBTM {
             }
          }
 
+         // Empty array to ensure than syncLdapGroups will be done
+         $this->fields["_groups"] = array();
+
          ///The groups are retrieved by looking into an ldap user object
          if ($ldap_method["group_search_type"] == 0 || $ldap_method["group_search_type"] == 2) {
             $this->getFromLDAPGroupVirtual($ldap_connection, $ldap_method, $userdn, $login);
@@ -1647,6 +1644,14 @@ class User extends CommonDBTM {
       $tab[82]['linkfield'] = 'usercategories_id';
       $tab[82]['name']      = $LANG['users'][2];
 
+      $tab[60]['table']        = 'glpi_tickets';
+      $tab[60]['field']        = 'count';
+      $tab[60]['linkfield']    = '';
+      $tab[60]['name']         = $LANG['stats'][13];
+      $tab[60]['forcegroupby'] = true;
+      $tab[60]['usehaving']    = true;
+      $tab[60]['datatype']     = 'number';
+
       return $tab;
    }
 
@@ -1670,8 +1675,9 @@ class User extends CommonDBTM {
                                        $used=array(), $search='') {
       global $DB, $CFG_GLPI;
 
+      // No entity define : use active ones
       if ($entity_restrict < 0) {
-         $entity_restrict = $_SESSION["glpiactive_entity"];
+         $entity_restrict = $_SESSION["glpiactiveentities"];
       }
       $joinprofile = false;
       switch ($right) {
@@ -2287,7 +2293,7 @@ class User extends CommonDBTM {
 
       $query = "SELECT `id`
                 FROM `glpi_users`
-                WHERE `name` = '$login'";
+                WHERE `name` = '".addslashes($login)."'";
       $result = $DB->query($query);
 
       if ($DB->numrows($result) == 1) {
