@@ -370,13 +370,13 @@ Ext.ux.form.DateTime = Ext.extend(Ext.form.Field, {
         if(this.isRendered) {
             this.df.disabled = this.disabled;
             this.df.onDisable();
-            this.tf.onDisable();
+//             this.tf.onDisable();
             this.hf.onDisable();
             this.mf.onDisable();
         }
         this.disabled = true;
         this.df.disabled = true;
-        this.tf.disabled = true;
+//         this.tf.disabled = true;
         this.hf.disabled = true;
         this.mf.disabled = true;
         this.fireEvent("disable", this);
@@ -391,13 +391,13 @@ Ext.ux.form.DateTime = Ext.extend(Ext.form.Field, {
     ,enable:function() {
         if(this.rendered){
             this.df.onEnable();
-            this.tf.onEnable();
+//             this.tf.onEnable();
             this.hf.onEnable();
             this.mf.onEnable();
         }
         this.disabled = false;
         this.df.disabled = false;
-        this.tf.disabled = false;
+//         this.tf.disabled = false;
         this.hf.disabled = false;
         this.mf.disabled = false;
         this.fireEvent("enable", this);
