@@ -45,6 +45,7 @@ $LANG['backup'][23]="Error MySQL començant a";
 $LANG['backup'][24]="Redirecció automàtica. Si no és així, fes clic"; 
 
 $LANG['bookmark'][1]="marcador"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="No té marcadors guardats"; 
 $LANG['bookmark'][4]="Nou marcador"; 
 $LANG['bookmark'][5]="Marcadors Públics"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="Contrasenya d'usuari OCSweb";
 $LANG['ocsconfig'][4]="Nom de la base de dades OCSNG"; 
 $LANG['ocsconfig'][5]="Opcions d'importació"; 
 $LANG['ocsconfig'][6]="Ignorar la importació des d'OCSNG"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Excloure les següents etiquetes (separador $, res per ningú)"; 
 $LANG['ocsconfig'][10]="Importació global"; 
 $LANG['ocsconfig'][11]="No importar"; 
