@@ -45,6 +45,7 @@ $LANG['backup'][23]="Chyba Mysql začíná na";
 $LANG['backup'][24]="Automatické přesměrování, jinak klikněte"; 
 
 $LANG['bookmark'][1]="záložka"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Zatím nemáte žádné záložky."; 
 $LANG['bookmark'][4]="Nová záložka"; 
 $LANG['bookmark'][5]="Public bookmarks"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Volby importu"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Vynechat následující tagy (oddělovač $, zrušit vše)"; 
 $LANG['ocsconfig'][10]="Souhrnný import"; 
 $LANG['ocsconfig'][11]="Žádný import"; 
