@@ -45,6 +45,7 @@ $LANG['backup'][23]="MySQL fejl startende ved";
 $LANG['backup'][24]="Automatisk viderestilling, ellers klik"; 
 
 $LANG['bookmark'][1]="bogmærke"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Du har endnu ikke angivet bogmærker"; 
 $LANG['bookmark'][4]="Nyt bogmærke"; 
 $LANG['bookmark'][5]="Offentligt bogmærke"; 
@@ -59,7 +60,7 @@ $LANG['buttons'][6]="Slet";
 $LANG['buttons'][7]="Opdatér"; 
 $LANG['buttons'][8]="Tilføj"; 
 $LANG['buttons'][9]="Forbind"; 
-$LANG['buttons'][10]="Disconnect"; 
+$LANG['buttons'][10]="Frakobl"; 
 $LANG['buttons'][11]="Næste"; 
 $LANG['buttons'][12]="Forrige"; 
 $LANG['buttons'][13]="Tilbage"; 
@@ -268,7 +269,7 @@ $LANG['common'][82]="MB";
 $LANG['common'][83]="Du har ikke rettighed til at udføre denne handling."; 
 $LANG['common'][84]="Flag change forbidden. Linked items found."; 
 $LANG['common'][85]="Tilpas synlighed for under-entiteter"; 
-$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
+$LANG['common'][86]="Du har ikke tilladelse til at ændre synlighedsflaget for underentiteter."; 
 $LANG['common'][87]="Nyt kort"; 
 $LANG['common'][88]="Personlig"; 
 $LANG['common'][89]="Ikke installeret"; 
@@ -442,7 +443,7 @@ $LANG['document'][24]="Filen blev slettet";
 $LANG['document'][25]="Kunne ikke slette filen"; 
 $LANG['document'][26]="Filen er gyldig. Upload lykkedes"; 
 $LANG['document'][27]="Potetiel upload angreb, eller filen er for stor. Flytning af temp fil mislykkedes."; 
-$LANG['document'][28]="No file specified."; 
+$LANG['document'][28]="Ingen fil angivet."; 
 $LANG['document'][29]="Kunne ikke oprette biblioteket"; 
 $LANG['document'][30]="Kontrollér om du har de rigtige rettigheder"; 
 $LANG['document'][31]="Mappe til dokumenter eksisterer ikke"; 
@@ -868,7 +869,7 @@ $LANG['log'][21]="opdater emne";
 $LANG['log'][22]="Slet"; 
 $LANG['log'][23]="gendan emne"; 
 $LANG['log'][24]="slet emne"; 
-$LANG['log'][26]="disconnect item"; 
+$LANG['log'][26]="frakobl emne"; 
 $LANG['log'][27]="emne forbindelse"; 
 $LANG['log'][28]="opdater komponenter"; 
 $LANG['log'][29]="godkendelse/afvisning af løsning"; 
@@ -999,7 +1000,7 @@ $LANG['mailing'][40]="Emner ankommet efter garanti:";
 $LANG['mailing'][41]="Finans alarm"; 
 $LANG['mailing'][42]="Ændring i time-omkostninger"; 
 $LANG['mailing'][43]="Ændring i faste omkostninger"; 
-$LANG['mailing'][44]="Change in material costs"; 
+$LANG['mailing'][44]="Ændring i materiale pris"; 
 $LANG['mailing'][45]="Skift sagens titel"; 
 $LANG['mailing'][46]="Skift sagens beskrivelse"; 
 $LANG['mailing'][47]="Fejl ved afsendelse af email"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG bruger-password";
 $LANG['ocsconfig'][4]="Navn på OCSNG databasen"; 
 $LANG['ocsconfig'][5]="Import muligheder"; 
 $LANG['ocsconfig'][6]="Ignorér i OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Ekskludér følgende tags (separator $, ingenting for alle)"; 
 $LANG['ocsconfig'][10]="Global import"; 
 $LANG['ocsconfig'][11]="Ingen import"; 
@@ -1290,12 +1292,12 @@ $LANG['profiles'][23]="Administration af reservationer";
 $LANG['profiles'][24]="Opdater kode"; 
 $LANG['profiles'][26]="Vis sager oprettet af mine grupper"; 
 $LANG['profiles'][27]="Se min gruppes hardware"; 
-$LANG['profiles'][28]="Recursive"; 
+$LANG['profiles'][28]="Rekursiv"; 
 $LANG['profiles'][29]="Dynamisk"; 
 $LANG['profiles'][30]="Vis OCSNG information"; 
 $LANG['profiles'][31]="Synkroniser OCSNG manuelt"; 
 $LANG['profiles'][32]="Se tilknyttede sager (personligt og gruppe associeret)"; 
-$LANG['profiles'][33]="No user founded"; 
+$LANG['profiles'][33]="Ingen bruger fundet"; 
 $LANG['profiles'][34]="Overskrift"; 
 $LANG['profiles'][35]="Opdatér alle opfølgninger"; 
 $LANG['profiles'][36]="Se kalender for personer i mine grupper"; 
@@ -1537,7 +1539,7 @@ $LANG['setup'][43]="Printer typer";
 $LANG['setup'][44]="Skærmtyper"; 
 $LANG['setup'][45]="Sags type"; 
 $LANG['setup'][46]="Standardværdi"; 
-$LANG['setup'][47]="Default chart format"; 
+$LANG['setup'][47]="Standard diagram format"; 
 $LANG['setup'][48]="Standardværdier"; 
 $LANG['setup'][62]="Vælg kategori der skal konfigureres"; 
 $LANG['setup'][63]="Forsigtig: Du er ved at slette en overskrift brugt til 1 eller flere ting."; 
@@ -1643,7 +1645,7 @@ $LANG['setup'][182]="Logout fallback URL";
 $LANG['setup'][185]="Logs i filer (SQL, e-mail, automatisk hændelse...)"; 
 $LANG['setup'][186]="Tidszone"; 
 $LANG['setup'][190]="x509 certifikat"; 
-$LANG['setup'][191]="email attribute for x509"; 
+$LANG['setup'][191]="email-attribut for x509"; 
 $LANG['setup'][192]="Aktiveret"; 
 $LANG['setup'][193]="Field holding the login in the _SERVER array"; 
 $LANG['setup'][194]="Yderligere informationshentning fra LDAP bibliotek"; 
@@ -1759,7 +1761,7 @@ $LANG['setup'][650]="PHP";
 $LANG['setup'][651]="SMTP"; 
 $LANG['setup'][652]="SMTP+SSL"; 
 $LANG['setup'][653]="SMTP+TLS"; 
-$LANG['setup'][660]="Mail server"; 
+$LANG['setup'][660]="Mailserver"; 
 $LANG['setup'][661]="Kunne ikke konfigurere påmindelserne : aktiver venligst e-mail overvågning"; 
 $LANG['setup'][703]="Generel"; 
 $LANG['setup'][704]="Påmindelser"; 
@@ -1879,7 +1881,7 @@ $LANG['tracking'][38]="En email blev sendt til";
 $LANG['tracking'][39]="Synlig i den simple brugerflade"; 
 
 $LANG['transfer'][1]="Overfør"; 
-$LANG['transfer'][3]="If no longer in use"; 
+$LANG['transfer'][3]="Hvis ikke længere i brug"; 
 $LANG['transfer'][4]="For at tømme listen med emner der skal overføres"; 
 $LANG['transfer'][5]="Du kan fortsætte med at tilføje emner der skal overføres eller udføre overførslen nu"; 
 $LANG['transfer'][6]="Think of making a backup before transferring items."; 
@@ -1921,10 +1923,10 @@ $LANG['validation'][2]="Status";
 $LANG['validation'][3]="Request date"; 
 $LANG['validation'][4]="Valideringsdato"; 
 $LANG['validation'][5]="Request comment"; 
-$LANG['validation'][6]="Approval comment"; 
+$LANG['validation'][6]="Godkendelses kommentar"; 
 $LANG['validation'][7]="Validering(er) af sagen"; 
 $LANG['validation'][9]="Venter på validering"; 
-$LANG['validation'][10]="Refused"; 
+$LANG['validation'][10]="Afvist"; 
 $LANG['validation'][11]="Accepteret"; 
 $LANG['validation'][12]="Not subject to approval"; 
 $LANG['validation'][13]="Approval request send to"; 
