@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql error starting from";
 $LANG['backup'][24]="Automatic redirection, else click"; 
 
 $LANG['bookmark'][1]="bookmark"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="You have not recorded any bookmarks yet."; 
 $LANG['bookmark'][4]="New bookmark"; 
 $LANG['bookmark'][5]="Public bookmarks"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Import Options"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
 $LANG['ocsconfig'][10]="Global import"; 
 $LANG['ocsconfig'][11]="No import"; 
