@@ -45,6 +45,7 @@ $LANG['backup'][23]="Error MySQL a partir de";
 $LANG['backup'][24]="Automatic redirection, else click"; 
 
 $LANG['bookmark'][1]="Marcadores"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="No has guardado ningún marcador aún."; 
 $LANG['bookmark'][4]="Nuevo Marcador"; 
 $LANG['bookmark'][5]="Marcadores Publicos"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Opciones de importación"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
 $LANG['ocsconfig'][10]="Importación global"; 
 $LANG['ocsconfig'][11]="No hay importaciones"; 
@@ -1528,7 +1530,7 @@ $LANG['setup'][18]="Login";
 $LANG['setup'][19]="Password"; 
 $LANG['setup'][20]="Password confirmation"; 
 $LANG['setup'][21]="Error : the two passwords are not identical"; 
-$LANG['setup'][35]="MHZ"; 
+$LANG['setup'][35]="MHz"; 
 $LANG['setup'][39]="Followed private for default"; 
 $LANG['setup'][40]="Private tasks by default"; 
 $LANG['setup'][41]="Idioma"; 
