@@ -45,6 +45,7 @@ $LANG['backup'][23]="Error MySQL empezando en";
 $LANG['backup'][24]="Redirección automática. Si no es así, haga clic"; 
 
 $LANG['bookmark'][1]="marcador"; 
+$LANG['bookmark'][2]="Carga parcial del marcador"; 
 $LANG['bookmark'][3]="No tiene marcadores guardados"; 
 $LANG['bookmark'][4]="Nuevo marcador"; 
 $LANG['bookmark'][5]="Marcadores Públicos"; 
@@ -437,12 +438,12 @@ $LANG['document'][18]="Documento";
 $LANG['document'][19]="Elementos asociados"; 
 $LANG['document'][21]="Documentos Asociados"; 
 $LANG['document'][22]="Fichero actual"; 
-$LANG['document'][23]="File too large to be added."; 
+$LANG['document'][23]="El archivo es demasiado grande para ser añadido."; 
 $LANG['document'][24]="Borrado correcto del fichero"; 
 $LANG['document'][25]="Falló el borrado del fichero"; 
 $LANG['document'][26]="El fichero es válido, y ha sido descargado correctamente."; 
 $LANG['document'][27]="Potencial ataque por upload, o fichero demasiado grande. Imposible mover el fichero temporal."; 
-$LANG['document'][28]="No file specified."; 
+$LANG['document'][28]="No se ha especificado ningún fichero"; 
 $LANG['document'][29]="Falló la creación del directorio"; 
 $LANG['document'][30]="Compruebe que tiene permisos"; 
 $LANG['document'][31]="Directorio de almacenamiento de documentos inexistente:"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="Contraseña de usuario OCSweb";
 $LANG['ocsconfig'][4]="Nombre de la base de datos OCSNG"; 
 $LANG['ocsconfig'][5]="Opciones de importación"; 
 $LANG['ocsconfig'][6]="Ignorar la importación desde OCSNG"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Excluir las siguientes etiquetas (separador $, nada para todas)"; 
 $LANG['ocsconfig'][10]="Importación global"; 
 $LANG['ocsconfig'][11]="No importar"; 
@@ -1253,7 +1255,7 @@ $LANG['plugins'][6]="A actualizar";
 $LANG['plugins'][7]="Ningún plugin instalado"; 
 $LANG['plugins'][8]="Ver listado de plugins"; 
 $LANG['plugins'][9]="Autores"; 
-$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 
+$LANG['plugins'][10]="Plugin incompatible con esta versión de GLPI"; 
 
 $LANG['printers'][14]="Serie"; 
 $LANG['printers'][15]="Paralelo"; 
@@ -1926,7 +1928,7 @@ $LANG['validation'][7]="Validación(es) para la incidencia";
 $LANG['validation'][9]="En espera de validación"; 
 $LANG['validation'][10]="Rechazado"; 
 $LANG['validation'][11]="Aceptada"; 
-$LANG['validation'][12]="Not subject to approval"; 
+$LANG['validation'][12]="No está sujeto a la validación"; 
 $LANG['validation'][13]="Solicitud de validación enviada a"; 
 $LANG['validation'][15]="Incidencia en espera de su validación"; 
 $LANG['validation'][16]="Opcional si aceptada"; 
