@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: fr_FR.php 12991 2010-11-08 14:43:45Z remi $
+ * @version $Id: fr_FR.php 13658 2011-01-18 10:58:45Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -49,7 +49,7 @@ $LANG['backup'][24] = "Redirection automatique, sinon cliquez";
 
 
 $LANG['bookmark'][1] = "marque-page";
-
+$LANG['bookmark'][2] = "Chargement partiel du marque-page.";
 $LANG['bookmark'][3] = "Vous n'avez pas encore enregistré de marque-pages.";
 $LANG['bookmark'][4] = "Nouveau marque-page";
 $LANG['bookmark'][5] = "Marque-pages publics";
@@ -1287,6 +1287,7 @@ $LANG['ocsconfig'][3]="Mot de passe de l'utilisateur OCSNG";
 $LANG['ocsconfig'][4]="Nom de la base de données OCSNG";
 $LANG['ocsconfig'][5]="Options d'importation";
 $LANG['ocsconfig'][6]="Ignorer lors de l'import OCSNG";
+$LANG['ocsconfig'][7]="Base de données OCSNG en UTF8";
 $LANG['ocsconfig'][9]="Exclure les tags suivants (séparateur $, rien pour aucun)";
 $LANG['ocsconfig'][10]="Import global";
 $LANG['ocsconfig'][11]="Pas d'import";
@@ -1663,8 +1664,8 @@ $LANG['rulesengine'][140]="Ajout d'un critère";
 $LANG['rulesengine'][142]="Liste des emails non importés";
 $LANG['rulesengine'][144]="Entité depuis profil de l'utilisateur";
 $LANG['rulesengine'][145]="Utilisateur possédant un seul profil";
-$LANG['rulesengine'][146]="Utilisateur possèdant le profil";
-$LANG['rulesengine'][147]="Utilisateur possèdant une seule fois le profil";
+$LANG['rulesengine'][146]="Utilisateur possédant le profil";
+$LANG['rulesengine'][147]="Utilisateur possédant une seule fois le profil";
 $LANG['rulesengine'][148]="Domaine de messagerie connu";
 
 $LANG['rulesengine'][150]="Les règles affectées à l'entité ont été désactivées.";
@@ -1699,7 +1700,7 @@ $LANG['setup'][18]="Identifiant";
 $LANG['setup'][19]="Mot de passe";
 $LANG['setup'][20]="Confirmation mot de passe";
 $LANG['setup'][21]="Erreur : les deux mots de passe ne sont pas identiques";
-$LANG['setup'][35]="MHZ";
+$LANG['setup'][35]="MHz";
 $LANG['setup'][39]="Suivis privés par défaut";
 $LANG['setup'][40]="Tâches privées par défaut";
 $LANG['setup'][41]="Langue";
@@ -2107,8 +2108,8 @@ $LANG['validation'][5]="Commentaire de la demande";
 $LANG['validation'][6]="Commentaire de la validation";
 $LANG['validation'][7]="Validation(s) pour le ticket";
 $LANG['validation'][9]="En attente de validation";
-$LANG['validation'][10]="Refusé";
-$LANG['validation'][11]="Accepté";
+$LANG['validation'][10]="Refusée";
+$LANG['validation'][11]="Acceptée";
 $LANG['validation'][12]="Non soumis à validation";
 $LANG['validation'][13]="Demande de validation envoyée à";
 $LANG['validation'][15]="Ticket attendant votre validation";
