@@ -45,6 +45,7 @@ $LANG['backup'][23]="Erro MySQL empezando en";
 $LANG['backup'][24]="Redirección automática. Si non é así, faga clic"; 
 
 $LANG['bookmark'][1]="marcapáxinas"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Non ten marcadores gardados"; 
 $LANG['bookmark'][4]="Novo marcador"; 
 $LANG['bookmark'][5]="Marcadores Públicos"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Opcións de importación"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Excluir as seguintes etiquetas (separador $, nada para todas)"; 
 $LANG['ocsconfig'][10]="Importación global"; 
 $LANG['ocsconfig'][11]="Non importar"; 
