@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql greška pokrenuta od";
 $LANG['backup'][24]="Automatska redirekcija, opcija je klik"; 
 
 $LANG['bookmark'][1]="podsjetnik"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Niste još spremili ni jedan podsjetnik."; 
 $LANG['bookmark'][4]="Novi podsjetnik"; 
 $LANG['bookmark'][5]="Javni podsjetnik"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Opcije uvoza"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Izostavi sljedeće znakove (separator $, ništa za sve)"; 
 $LANG['ocsconfig'][10]="Masovni uvoz"; 
 $LANG['ocsconfig'][11]="Nema uvoza"; 
