@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql hiba";
 $LANG['backup'][24]="Automatikus átirányítás"; 
 
 $LANG['bookmark'][1]="könyvjelző"; 
+$LANG['bookmark'][2]="Könyvjelző részleges betöltése."; 
 $LANG['bookmark'][3]="Nem vettél fel könyvjelzőt"; 
 $LANG['bookmark'][4]="Új könyvjelző"; 
 $LANG['bookmark'][5]="Nyilvános könyvjelzők"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="Az OCSweb felhasználó jelszava";
 $LANG['ocsconfig'][4]="Az OCS adatbázis neve"; 
 $LANG['ocsconfig'][5]="Import lehetőségek"; 
 $LANG['ocsconfig'][6]="Kihagyás ocs importból"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Kihagyja a következő címkéket (elválasztó : $, üresen hagy : minden)"; 
 $LANG['ocsconfig'][10]="Globális import"; 
 $LANG['ocsconfig'][11]="Nincs import"; 
@@ -1926,7 +1928,7 @@ $LANG['validation'][7]="Bejelentés érvényesítései";
 $LANG['validation'][9]="Érvényesítésre vár"; 
 $LANG['validation'][10]="Visszautasított"; 
 $LANG['validation'][11]="Elfogadva"; 
-$LANG['validation'][12]="Not subject to approval"; 
+$LANG['validation'][12]="Nem képezi jóváhagyás tárgyát"; 
 $LANG['validation'][13]="Érvényesítés kérelem elküldve"; 
 $LANG['validation'][15]="Bejelentés érvényesítésre vár"; 
 $LANG['validation'][16]="Elfogadás esetén nem kötelező"; 
