@@ -45,6 +45,7 @@ $LANG['backup'][23]="Errore MySQL iniziando da";
 $LANG['backup'][24]="Reindirizzamento automatico, oppure fai clic qui"; 
 
 $LANG['bookmark'][1]="segnalibro"; 
+$LANG['bookmark'][2]="Caricamento parziale del segnalibro."; 
 $LANG['bookmark'][3]="Non hai segnalibri memorizzati."; 
 $LANG['bookmark'][4]="Nuovo segnalibro"; 
 $LANG['bookmark'][5]="Segnalibri pubblici"; 
@@ -102,7 +103,7 @@ $LANG['buttons'][52]="Carica";
 $LANG['buttons'][53]="Pulisci"; 
 $LANG['buttons'][55]="Primo"; 
 $LANG['buttons'][56]="Ultimo"; 
-$LANG['buttons'][57]="Esugui"; 
+$LANG['buttons'][57]="Esegui"; 
 $LANG['buttons'][58]="Aggiorna"; 
 $LANG['buttons'][59]="Dissocia"; 
 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="Password dell'utente OCS-NG";
 $LANG['ocsconfig'][4]="Nome del database OCS-NG"; 
 $LANG['ocsconfig'][5]="Opzioni di importazione"; 
 $LANG['ocsconfig'][6]="Ignoralo nell'importazione OCS-NG"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Escludi i seguenti tag (usa $ come separatore, se assente include tutti)"; 
 $LANG['ocsconfig'][10]="Importazione globale"; 
 $LANG['ocsconfig'][11]="Non importare"; 
