@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysqlエラー：";
 $LANG['backup'][24]="自動転送、さもなくばクリック"; 
 
 $LANG['bookmark'][1]="ブックマーク"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="まだブックマークを行っていません。"; 
 $LANG['bookmark'][4]="新しいブックマーク"; 
 $LANG['bookmark'][5]="公開ブックマーク"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNGユーザーパスワード";
 $LANG['ocsconfig'][4]="OCSNGデータベース名"; 
 $LANG['ocsconfig'][5]="インポートのオプション"; 
 $LANG['ocsconfig'][6]="OCSNGインポートでは無視"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="以下のタグは除外します。（区切り文字は＄で、＄自体は意味を持ちません）"; 
 $LANG['ocsconfig'][10]="グローバルインポート"; 
 $LANG['ocsconfig'][11]="インポート無し"; 
