@@ -45,10 +45,11 @@ $LANG['backup'][23]="Mysql klaida, pradedant nuo";
 $LANG['backup'][24]="Automatinis peradresavimas, arba spustelti"; 
 
 $LANG['bookmark'][1]="skirtukas"; 
+$LANG['bookmark'][2]="Dalinis skirtuko įkėlimas"; 
 $LANG['bookmark'][3]="Nėra išsaugotų skirtukų"; 
 $LANG['bookmark'][4]="Naujas skirtukas"; 
 $LANG['bookmark'][5]="Vieši skirtukai"; 
-$LANG['bookmark'][6]="Pritaikyti kaip numatytus"; 
+$LANG['bookmark'][6]="Numatytasis rodymas"; 
 
 $LANG['buttons'][0]="Paieška"; 
 $LANG['buttons'][2]="Toliau"; 
@@ -98,13 +99,13 @@ $LANG['buttons'][48]="Perkelti";
 $LANG['buttons'][49]="Išlaikyti"; 
 $LANG['buttons'][50]="Tikrinti"; 
 $LANG['buttons'][51]="Išsaugoti"; 
-$LANG['buttons'][52]="Įkrauti"; 
+$LANG['buttons'][52]="Įkelti"; 
 $LANG['buttons'][53]="Išvalyti"; 
 $LANG['buttons'][55]="Pirmas"; 
 $LANG['buttons'][56]="Paskutinis"; 
-$LANG['buttons'][57]="Execute"; 
-$LANG['buttons'][58]="Update"; 
-$LANG['buttons'][59]="Dissociate"; 
+$LANG['buttons'][57]="Vykdyti"; 
+$LANG['buttons'][58]="Atnaujinti"; 
+$LANG['buttons'][59]="Atsieti"; 
 
 $LANG['calendar'][0]="YYYY-MM-DD"; 
 $LANG['calendar'][1]="DD-MM-YYYY"; 
@@ -262,7 +263,7 @@ $LANG['common'][76]="Bendras";
 $LANG['common'][77]="Asmeninis"; 
 $LANG['common'][78]="Nustatyti viešu"; 
 $LANG['common'][79]="Set personal"; 
-$LANG['common'][80]="Įkrovimas..."; 
+$LANG['common'][80]="Įkėlimas..."; 
 $LANG['common'][81]="Don't show deleted items"; 
 $LANG['common'][82]="MB"; 
 $LANG['common'][83]="You don't have permission to perform this action."; 
@@ -281,7 +282,7 @@ $LANG['computers'][0]="Volume";
 $LANG['computers'][1]="Free percentage"; 
 $LANG['computers'][2]="Laisvos apimties"; 
 $LANG['computers'][3]="Global size"; 
-$LANG['computers'][4]="File system"; 
+$LANG['computers'][4]="Rinkmenų išdėstymo sistema"; 
 $LANG['computers'][5]="Mount point"; 
 $LANG['computers'][6]="Partition"; 
 $LANG['computers'][7]="Pridėti saugyklą"; 
@@ -374,12 +375,12 @@ $LANG['crontask'][48]="Start";
 $LANG['crontask'][50]="Run count"; 
 $LANG['crontask'][51]="Minimal time"; 
 $LANG['crontask'][52]="Maximal time"; 
-$LANG['crontask'][53]="Average time"; 
+$LANG['crontask'][53]="Trukmė (vidurkis)"; 
 $LANG['crontask'][55]="Minimal count"; 
 $LANG['crontask'][56]="Maximal count"; 
-$LANG['crontask'][57]="Average count"; 
+$LANG['crontask'][57]="Kiekis (vidurkis)"; 
 $LANG['crontask'][58]="Total count"; 
-$LANG['crontask'][59]="Average speed"; 
+$LANG['crontask'][59]="Sparta (vidurkis)"; 
 $LANG['crontask'][60]="System lock"; 
 $LANG['crontask'][61]="Disabled plugin"; 
 $LANG['crontask'][62]="Elements"; 
@@ -441,7 +442,7 @@ $LANG['document'][23]="File too large to be added.";
 $LANG['document'][24]="Sėkmingas rinkmenos pašalinimas"; 
 $LANG['document'][25]="Nepavyko pašalinti rinkmenos"; 
 $LANG['document'][26]="Rinkmena nepažeista. Išsiuntimas sėkmingas."; 
-$LANG['document'][27]="Išsiuntimo sutrikimai, arba rinkmena per didelė. Laikonos rinkmenos perkėlimas nepavyko."; 
+$LANG['document'][27]="Išsiuntimo sutrikimai, arba rinkmena per didelė. Laikinos rinkmenos perkėlimas nepavyko."; 
 $LANG['document'][28]="No file specified."; 
 $LANG['document'][29]="Nepavyko sukurti aplanko"; 
 $LANG['document'][30]="Patikrinkite ar yra reikalingos prieeigos teisės"; 
@@ -462,7 +463,7 @@ $LANG['document'][44]="Netinkamas vardas";
 $LANG['document'][45]="Nėra reikalingų prieeigos teisių šiai rinkmenai"; 
 $LANG['document'][46]="Nepavyko išsiųsti rinkmenos (per didelė apimtis)"; 
 $LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
-$LANG['document'][49]="File is altered (bad checksum)"; 
+$LANG['document'][49]="Rinkmena pakitusi (kontrolinė suma neatitinka)"; 
 $LANG['document'][50]="Attached items"; 
 
 $LANG['entity'][0]="Padalinys"; 
@@ -638,8 +639,8 @@ $LANG['install'][17]="Rinkmena nesukurta";
 $LANG['install'][18]="Unofficial translations are also available"; 
 $LANG['install'][19]="Rinkmena sukurta bet jos pašalinti neleidžiama"; 
 $LANG['install'][20]="Rinkmena ir aplankas buvo sukurti ir pašalinti - Puiku!"; 
-$LANG['install'][21]="Tikrinama rašymo leidimai dokumnentų rinkmenoms"; 
-$LANG['install'][22]="Failas sukurtas - Puiku !"; 
+$LANG['install'][21]="Tikrinama rašymo leidimai dokumentų rinkmenoms"; 
+$LANG['install'][22]="Rinkmena sukurta - Puiku !"; 
 $LANG['install'][23]="Tikrinami rašymo leidimai nustatymų rinkmenoms"; 
 $LANG['install'][24]="Initialization of the database"; 
 $LANG['install'][25]="Tęsti?"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Įkelties sąlygos"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
 $LANG['ocsconfig'][10]="Visuminis įkėlimas"; 
 $LANG['ocsconfig'][11]="Nėra įkelties"; 
