@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql kļūda sākot no";
 $LANG['backup'][24]="Automātiska pradresācija, lai atceltu - noklikšķiniet"; 
 
 $LANG['bookmark'][1]="grāmatzīme"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Jums nav saglabāta neviena grāmatzīme."; 
 $LANG['bookmark'][4]="Jauna grāmatzīme"; 
 $LANG['bookmark'][5]="Publiskās grāmatzīmes"; 
@@ -101,14 +102,14 @@ $LANG['buttons'][51]="Saglabāt";
 $LANG['buttons'][52]="Ielādēt"; 
 $LANG['buttons'][53]="Clean"; 
 $LANG['buttons'][55]="First"; 
-$LANG['buttons'][56]="Last"; 
+$LANG['buttons'][56]="Pēdējais"; 
 $LANG['buttons'][57]="Execute"; 
-$LANG['buttons'][58]="Update"; 
+$LANG['buttons'][58]="Atjaunināt"; 
 $LANG['buttons'][59]="Dissociate"; 
 
-$LANG['calendar'][0]="YYYY-MM-DD"; 
-$LANG['calendar'][1]="DD-MM-YYYY"; 
-$LANG['calendar'][2]="MM-DD-YYYY"; 
+$LANG['calendar'][0]="GGGG-MM-DD"; 
+$LANG['calendar'][1]="DD-MM-GGGG"; 
+$LANG['calendar'][2]="MM-DD-GGGG"; 
 
 $LANG['calendarD'][0]="S"; 
 $LANG['calendarD'][1]="P"; 
@@ -271,7 +272,7 @@ $LANG['common'][85]="Change visibility in the child entities";
 $LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
 $LANG['common'][87]="New card"; 
 $LANG['common'][88]="Personal"; 
-$LANG['common'][89]="Not installed"; 
+$LANG['common'][89]="Nav uzstādīts"; 
 $LANG['common'][90]="Object"; 
 $LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
 $LANG['common'][92]="Alternate username"; 
@@ -370,7 +371,7 @@ $LANG['crontask'][44]="Action completed, partially processed";
 $LANG['crontask'][45]="Action completed, fully processed"; 
 $LANG['crontask'][46]="Action completed, no processing required"; 
 $LANG['crontask'][47]="Last run list"; 
-$LANG['crontask'][48]="Start"; 
+$LANG['crontask'][48]="Sākt"; 
 $LANG['crontask'][50]="Run count"; 
 $LANG['crontask'][51]="Minimal time"; 
 $LANG['crontask'][52]="Maximal time"; 
@@ -463,7 +464,7 @@ $LANG['document'][45]="Pieeja datnei slēgta";
 $LANG['document'][46]="Neizdevās nosūtīt datni. (par lielu?)"; 
 $LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
 $LANG['document'][49]="File is altered (bad checksum)"; 
-$LANG['document'][50]="Attached items"; 
+$LANG['document'][50]="Pievienoti vienumi"; 
 
 $LANG['entity'][0]="Nodaļa"; 
 $LANG['entity'][2]="Galvenā nodaļa"; 
@@ -714,7 +715,7 @@ $LANG['job'][2]="";
 $LANG['job'][4]="Iesniedzējs"; 
 $LANG['job'][5]="Piešķirts"; 
 $LANG['job'][6]="Tehniķis"; 
-$LANG['job'][7]="Task"; 
+$LANG['job'][7]="Sekojums"; 
 $LANG['job'][8]="last(s) ticket(s)"; 
 $LANG['job'][9]="Follow-up"; 
 $LANG['job'][11]="Aprakstiet problēmu/darbību"; 
@@ -726,7 +727,7 @@ $LANG['job'][20]="Atvēlētais laiks";
 $LANG['job'][21]="Stunda(s)"; 
 $LANG['job'][22]="Minūte(s)"; 
 $LANG['job'][29]="Pievienot jaunu sekojumu"; 
-$LANG['job'][30]="Add a new task"; 
+$LANG['job'][30]="Pievienot jaunu sekojumu"; 
 $LANG['job'][31]="Ilgums"; 
 $LANG['job'][32]="Nav"; 
 $LANG['job'][33]="Nav apraksta"; 
@@ -747,7 +748,7 @@ $LANG['job'][48]="Type of solution";
 $LANG['job'][49]="New task"; 
 $LANG['job'][50]="No task for this ticket"; 
 $LANG['job'][51]="Approval of the solution"; 
-$LANG['job'][52]="Update task"; 
+$LANG['job'][52]="Atjaunināt sekojumu"; 
 $LANG['job'][53]="Deletion of a task"; 
 $LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 
 
@@ -841,7 +842,7 @@ $LANG['ldap'][40]="Simple";
 $LANG['ldap'][41]="To change"; 
 $LANG['ldap'][42]="No directory selected"; 
 $LANG['ldap'][43]="No users to be synchronized"; 
-$LANG['ldap'][44]="Default server"; 
+$LANG['ldap'][44]="Noklusējuma serveris"; 
 $LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
 $LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
 $LANG['ldap'][47]="Put in trash"; 
@@ -852,7 +853,7 @@ $LANG['ldap'][52]="Less than";
 $LANG['ldap'][53]="More than"; 
 $LANG['ldap'][54]="Enable filtering by date"; 
 $LANG['ldap'][55]="Disable filtering by date"; 
-$LANG['ldap'][56]="Weeks"; 
+$LANG['ldap'][56]="Nedēļas"; 
 
 $LANG['links'][1]="Saite vai datnes nosaukums"; 
 $LANG['links'][4]="Saistītās aparatūras tips"; 
@@ -1021,8 +1022,8 @@ $LANG['mailing'][113]="Notification templates";
 $LANG['mailing'][114]="Body"; 
 $LANG['mailing'][115]="Main part of email"; 
 $LANG['mailing'][116]="HTML"; 
-$LANG['mailing'][117]="text"; 
-$LANG['mailing'][118]="Email"; 
+$LANG['mailing'][117]="teksts"; 
+$LANG['mailing'][118]="E-pasts"; 
 $LANG['mailing'][119]="Occurrence"; 
 $LANG['mailing'][120]="Notification method"; 
 $LANG['mailing'][121]="Recipients"; 
@@ -1034,10 +1035,10 @@ $LANG['mailing'][126]="Template translation";
 $LANG['mailing'][127]="Closing of the ticket"; 
 $LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
 $LANG['mailing'][129]="Deletion of a ticket"; 
-$LANG['mailing'][130]="From"; 
+$LANG['mailing'][130]="No"; 
 $LANG['mailing'][131]="Recipient"; 
 $LANG['mailing'][132]="Email header"; 
-$LANG['mailing'][133]="Delete email(s)"; 
+$LANG['mailing'][133]="Dzēst e-pastu(s)"; 
 $LANG['mailing'][134]="Updating follow-up"; 
 $LANG['mailing'][135]="Follow-up's deletion"; 
 $LANG['mailing'][136]="Reservation expired"; 
@@ -1046,7 +1047,7 @@ $LANG['mailing'][138]="List of available tags";
 $LANG['mailing'][139]="Label"; 
 $LANG['mailing'][140]="Tag"; 
 $LANG['mailing'][141]="Followups"; 
-$LANG['mailing'][142]="Tasks"; 
+$LANG['mailing'][142]="Sekojumi"; 
 $LANG['mailing'][143]="Validations"; 
 $LANG['mailing'][144]="Historical"; 
 $LANG['mailing'][145]="List of values"; 
@@ -1090,7 +1091,7 @@ $LANG['Menu'][37]="Nodaļas";
 $LANG['Menu'][38]="Inventārs"; 
 $LANG['Menu'][39]="Receivers"; 
 $LANG['Menu'][40]="Grāmatzīmes"; 
-$LANG['Menu'][41]="Rights"; 
+$LANG['Menu'][41]="Tiesības"; 
 
 $LANG['monitors'][14]="Mikrofons"; 
 $LANG['monitors'][15]="Skaļruņi"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Importēšanas uzstādījumi"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
 $LANG['ocsconfig'][10]="vispārējais imports (Global import)"; 
 $LANG['ocsconfig'][11]="Neimportēt"; 
@@ -1249,7 +1251,7 @@ $LANG['plugins'][2]="Installed / not configured";
 $LANG['plugins'][3]="Installed / not activated"; 
 $LANG['plugins'][4]="Error / to clean"; 
 $LANG['plugins'][5]="Non-existent function(s)"; 
-$LANG['plugins'][6]="To update"; 
+$LANG['plugins'][6]="Atjaunināt"; 
 $LANG['plugins'][7]="No plugin installed"; 
 $LANG['plugins'][8]="See the catalog of plugins"; 
 $LANG['plugins'][9]="Authors"; 
@@ -1259,7 +1261,7 @@ $LANG['printers'][14]="Seriālā";
 $LANG['printers'][15]="Paralēlā"; 
 $LANG['printers'][18]="Pieslēgvietas"; 
 $LANG['printers'][27]="USB"; 
-$LANG['printers'][28]="Ethernet"; 
+$LANG['printers'][28]="tīkls Ethernet"; 
 $LANG['printers'][29]="Wifi"; 
 $LANG['printers'][30]="Lapu skaitītāja sākotnējais rādījums"; 
 $LANG['printers'][31]="Izdrukātās lapas"; 
@@ -1571,7 +1573,7 @@ $LANG['setup'][96]="Printeru modeļi";
 $LANG['setup'][97]="Perifērijas modeļi"; 
 $LANG['setup'][98]="Tasks category"; 
 $LANG['setup'][99]="Building number"; 
-$LANG['setup'][100]="Room number"; 
+$LANG['setup'][100]="Telpas numurs"; 
 $LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
 $LANG['setup'][102]="Žurnalēšanas līmenis"; 
 $LANG['setup'][103]="1- Kritisks (tikai neveiksmīgas pieslēgšanās)"; 
@@ -1751,7 +1753,7 @@ $LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"
 $LANG['setup'][614]="Unable to update login. A user already exists."; 
 $LANG['setup'][615]="Life cycle of tickets"; 
 $LANG['setup'][616]="From \ To"; 
-$LANG['setup'][620]="Link"; 
+$LANG['setup'][620]="Saite"; 
 $LANG['setup'][621]="Search filter for entities"; 
 $LANG['setup'][622]="Attribute representing entity"; 
 $LANG['setup'][623]="Import entities from LDAP directory"; 
@@ -1800,7 +1802,7 @@ $LANG['software'][44]="Uzstādīt programmatūru";
 $LANG['software'][45]="Noinstalēt programmatūru"; 
 $LANG['software'][46]="Piesaistāms pieteikumam"; 
 $LANG['software'][47]="Merging"; 
-$LANG['software'][48]="Merge"; 
+$LANG['software'][48]="Apvienot"; 
 $LANG['software'][49]="Software deleted after merging"; 
 $LANG['software'][50]="Assigned to the computer"; 
 $LANG['software'][51]="The number must be 1 to be able to affect"; 
@@ -1915,32 +1917,32 @@ $LANG['update'][142]="Data migration";
 $LANG['users'][1]="Title"; 
 $LANG['users'][2]="Kategorija"; 
 
-$LANG['validation'][0]="Approval"; 
+$LANG['validation'][0]="Apstiprinājums"; 
 $LANG['validation'][1]="Send a Approval request"; 
-$LANG['validation'][2]="Status"; 
+$LANG['validation'][2]="Stāvoklis"; 
 $LANG['validation'][3]="Request date"; 
-$LANG['validation'][4]="Approval date"; 
+$LANG['validation'][4]="Apstiprinājuma datums"; 
 $LANG['validation'][5]="Request comment"; 
-$LANG['validation'][6]="Approval comment"; 
+$LANG['validation'][6]="Apstiprinājuma piezīmes"; 
 $LANG['validation'][7]="Approval(s) for the ticket"; 
 $LANG['validation'][9]="Waiting for approval"; 
 $LANG['validation'][10]="Refused"; 
 $LANG['validation'][11]="Granted"; 
 $LANG['validation'][12]="Not subject to approval"; 
-$LANG['validation'][13]="Approval request send to"; 
+$LANG['validation'][13]="Apstiprinājuma lūgumu sūtīt uz"; 
 $LANG['validation'][15]="Ticket waiting for your Approval"; 
 $LANG['validation'][16]="Optional when approved"; 
 $LANG['validation'][18]="Approval requester"; 
 $LANG['validation'][19]="Approval granted"; 
 $LANG['validation'][20]="Approval denied"; 
-$LANG['validation'][21]="Approver"; 
+$LANG['validation'][21]="Apstiprinātājs"; 
 $LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
-$LANG['validation'][26]="Approval request"; 
+$LANG['validation'][26]="Apstiprinājuma pieprasījums"; 
 $LANG['validation'][27]="An approval request has been submitted"; 
 $LANG['validation'][28]="Status of the Approval request"; 
 $LANG['validation'][29]="If approval is denied, specify a reason"; 
 $LANG['validation'][30]="Cancel the approval request to"; 
 $LANG['validation'][31]="Update the Approval request to"; 
 $LANG['validation'][32]="An answer to a Approval request was produced"; 
-$LANG['validation'][33]="Tickets awaiting approval"; 
+$LANG['validation'][33]="Pieteikums gaida apstiprinājumu"; 
 ?>
\ No newline at end of file
