@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql fout begint vanaf";
 $LANG['backup'][24]="Automatische omleiding, anders klikken"; 
 
 $LANG['bookmark'][1]="Bladwijzer"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="U heeft nu nog geen bladwijzer opgenomen."; 
 $LANG['bookmark'][4]="Nieuwe bladwijzer"; 
 $LANG['bookmark'][5]="Publieke bladwijzers"; 
@@ -437,12 +438,12 @@ $LANG['document'][18]="Document";
 $LANG['document'][19]="Geassocieerde items"; 
 $LANG['document'][21]="Geassocieerde documenten"; 
 $LANG['document'][22]="Huidig bestand"; 
-$LANG['document'][23]="File too large to be added."; 
+$LANG['document'][23]="Bestand is te groot om toe te voegen."; 
 $LANG['document'][24]="Het verwijderen van het bestand is gelukt"; 
 $LANG['document'][25]="Het verwijderen van het bestand is mislukt"; 
 $LANG['document'][26]="Het uploaden is gelukt"; 
 $LANG['document'][27]="Mogelijke upload-aanval, of bestand te groot"; 
-$LANG['document'][28]="No file specified."; 
+$LANG['document'][28]="Geen bestandsnaam opgegeven."; 
 $LANG['document'][29]="Map aanmaken niet gelukt"; 
 $LANG['document'][30]="Controleer of je de juiste rechten hebt."; 
 $LANG['document'][31]="Map voor documenten bestaat niet"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="Wachtwoord van de OCSNG-gebruiker";
 $LANG['ocsconfig'][4]="Naam van de OCS-database"; 
 $LANG['ocsconfig'][5]="Importopties"; 
 $LANG['ocsconfig'][6]="Negeer in de OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Sluit de volgende tags uit (scheidingsteken $, nothing voor alles)"; 
 $LANG['ocsconfig'][10]="Allesomvattende import"; 
 $LANG['ocsconfig'][11]="Geen import"; 
@@ -1253,7 +1255,7 @@ $LANG['plugins'][6]="Updaten";
 $LANG['plugins'][7]="Geen plugin geïnstalleerd"; 
 $LANG['plugins'][8]="Bekijk de lijst van plugins"; 
 $LANG['plugins'][9]="Auteurs"; 
-$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 
+$LANG['plugins'][10]="Plugin is niet compatible met deze versie van GLPI."; 
 
 $LANG['printers'][14]="Seriële poort"; 
 $LANG['printers'][15]="Parallelle poort"; 
@@ -1528,7 +1530,7 @@ $LANG['setup'][18]="Aanmelden";
 $LANG['setup'][19]="Wachtwoord"; 
 $LANG['setup'][20]="Password bevestiging"; 
 $LANG['setup'][21]="Fout ! de 2 passwords zijn niet identiek"; 
-$LANG['setup'][35]="MHZ"; 
+$LANG['setup'][35]="MHz"; 
 $LANG['setup'][39]="Private opvolging per default"; 
 $LANG['setup'][40]="Private taken per default"; 
 $LANG['setup'][41]="Kies de taal"; 
@@ -1926,7 +1928,7 @@ $LANG['validation'][7]="Validaties voor het Incident-ticket";
 $LANG['validation'][9]="Wachtrij validatie"; 
 $LANG['validation'][10]="Geweigerd"; 
 $LANG['validation'][11]="Geaccepteerd"; 
-$LANG['validation'][12]="Not subject to approval"; 
+$LANG['validation'][12]="Niet gevalideerd"; 
 $LANG['validation'][13]="Aanvraag validatie verzonden naar"; 
 $LANG['validation'][15]="Incident-ticket wacht op uw validatie"; 
 $LANG['validation'][16]="Facultatief in het geval van acceptatie"; 
