@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql feil starter ved";
 $LANG['backup'][24]="Automatisk omdirigering, Else klikk"; 
 
 $LANG['bookmark'][1]="Favoritter"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Du har ikke registrert noen bokmerker ennå."; 
 $LANG['bookmark'][4]="Nytt bokmerke"; 
 $LANG['bookmark'][5]="Offentlig bokmerker"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Import Instillinger"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Utelat følgende koder (separator $ ingenting for alle)"; 
 $LANG['ocsconfig'][10]="Global import"; 
 $LANG['ocsconfig'][11]="Ingen import"; 
