@@ -45,6 +45,7 @@ $LANG['backup'][23]="Erro Mysql, início em";
 $LANG['backup'][24]="Redireccionamento automático, caso contrário pressione"; 
 
 $LANG['bookmark'][1]="marcador"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Não tem marcadores guardados"; 
 $LANG['bookmark'][4]="Novo marcador"; 
 $LANG['bookmark'][5]="Marcadores Públicos"; 
@@ -1068,7 +1069,7 @@ $LANG['Menu'][15]="Administração";
 $LANG['Menu'][16]="Periféricos"; 
 $LANG['Menu'][17]="Reservas"; 
 $LANG['Menu'][18]="Ferramentas"; 
-$LANG['Menu'][19]="Knowledge base"; 
+$LANG['Menu'][19]="Base de Conhecimento"; 
 $LANG['Menu'][20]="FAQ"; 
 $LANG['Menu'][21]="Cartuchos"; 
 $LANG['Menu'][22]="Contactos"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Opções de importação"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
 $LANG['ocsconfig'][10]="Importação global"; 
 $LANG['ocsconfig'][11]="Sem importação"; 
@@ -1528,7 +1530,7 @@ $LANG['setup'][18]="Login";
 $LANG['setup'][19]="Password"; 
 $LANG['setup'][20]="Password confirmation"; 
 $LANG['setup'][21]="Error : the two passwords are not identical"; 
-$LANG['setup'][35]="MHZ"; 
+$LANG['setup'][35]="MHz"; 
 $LANG['setup'][39]="Followed private for default"; 
 $LANG['setup'][40]="Private tasks by default"; 
 $LANG['setup'][41]="Seleccione o idioma"; 
@@ -1574,9 +1576,9 @@ $LANG['setup'][99]="Building number";
 $LANG['setup'][100]="Room number"; 
 $LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
 $LANG['setup'][102]="Log Level"; 
-$LANG['setup'][103]="1- Critical (login error only)"; 
+$LANG['setup'][103]="1- Crítico (apenas erro de login)"; 
 $LANG['setup'][104]="2- Alta Importância(não usado)"; 
-$LANG['setup'][105]="3- Important (successful logins)"; 
+$LANG['setup'][105]="3- Importante (logins com sucesso)"; 
 $LANG['setup'][106]="4- Noticias (Adicionados, Excluídos, tracking)"; 
 $LANG['setup'][107]="5- Completo (Tudo)"; 
 $LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
@@ -1595,7 +1597,7 @@ $LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)
 $LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
 $LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
 $LANG['setup'][124]="Adicionar automaticamente um utilizador de uma fonte de autenticação externa"; 
-$LANG['setup'][125]="... From an external source"; 
+$LANG['setup'][125]="... De um fonte externa"; 
 $LANG['setup'][126]="Adicionar automaticamente utilizador de fonte externa"; 
 $LANG['setup'][127]="Autocompletion of text fields"; 
 $LANG['setup'][128]="Formato da data"; 
