@@ -45,6 +45,7 @@ $LANG['backup'][23]="Eroare MySQL incepând de la";
 $LANG['backup'][24]="Redirecționare automată, altfel faceți click"; 
 
 $LANG['bookmark'][1]="Semn de carte"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Nu ați salvat încă semnul de carte"; 
 $LANG['bookmark'][4]="Semn de carte nou"; 
 $LANG['bookmark'][5]="Semn de carte public"; 
@@ -700,7 +701,7 @@ $LANG['install'][93]="Am citit si ACCEPT termenii din licenta de mai sus.";
 $LANG['install'][94]="Am citit si NU ACCEPT termenii de licenta de mai jos"; 
 $LANG['install'][95]="Memorie nelimitata"; 
 $LANG['install'][96]="Memorie nelimitata"; 
-$LANG['install'][97]="Verificați permisiunile pe director:"; 
+$LANG['install'][97]="Verificați drepturile pe director:"; 
 $LANG['install'][99]="Se verifica permisiunea de a scrie pentru fisierele Cache"; 
 $LANG['install'][100]="Directorul nu a putut fi creat."; 
 $LANG['install'][101]="Directorul a fost creat, dar nu a putut fi indepartat"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Optiuni de importare"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Excludeti urmatoarele tag-uri (separator $, nimic pentru toate)"; 
 $LANG['ocsconfig'][10]="Import global"; 
 $LANG['ocsconfig'][11]="Nici un import"; 
@@ -1265,7 +1267,7 @@ $LANG['printers'][30]="Initial page counter";
 $LANG['printers'][31]="Pagini printate"; 
 
 $LANG['profiles'][0]="Drept global"; 
-$LANG['profiles'][1]="Entitate corecta"; 
+$LANG['profiles'][1]="Drept pentru entitate"; 
 $LANG['profiles'][2]="Interfața asociată la profil"; 
 $LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
 $LANG['profiles'][5]="Semnaleaza o problema"; 
