@@ -45,6 +45,7 @@ $LANG['backup'][23]="Chyba Mysql začína na";
 $LANG['backup'][24]="Automatické presmerovanie, inak kliknite"; 
 
 $LANG['bookmark'][1]="záložka"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Zatiaľ nemáte uložené žiadne záložky."; 
 $LANG['bookmark'][4]="Nová záložka"; 
 $LANG['bookmark'][5]="Verejné záložky"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="Heslo užívateľa OCSweb";
 $LANG['ocsconfig'][4]="Názov databázy OCS"; 
 $LANG['ocsconfig'][5]="Voľby importu"; 
 $LANG['ocsconfig'][6]="Ignorovať pri OCSNG importe"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Vyhechať nasledujúce tagy (oddeľovač $, nič pre všetko)"; 
 $LANG['ocsconfig'][10]="Globálny import"; 
 $LANG['ocsconfig'][11]="Žiaden import"; 
@@ -1261,7 +1263,7 @@ $LANG['printers'][18]="Porty";
 $LANG['printers'][27]="USB"; 
 $LANG['printers'][28]="Ethernet"; 
 $LANG['printers'][29]="Wifi"; 
-$LANG['printers'][30]="Číslo prvej stránky"; 
+$LANG['printers'][30]="Počiatočný počet stránok"; 
 $LANG['printers'][31]="Vytlačených stránok"; 
 
 $LANG['profiles'][0]="Globálne oprávnenia"; 
