@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql napaka, ki se začne iz";
 $LANG['backup'][24]="Samodejno preusmerjanje, drugače kliknite"; 
 
 $LANG['bookmark'][1]="zaznamek"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Niste še shranili nobenega zaznamka."; 
 $LANG['bookmark'][4]="Nov zaznamek"; 
 $LANG['bookmark'][5]="Javni zaznamki"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Možnosti uvoza"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Izključi naslednje znake (ločilo $, nič za vse)"; 
 $LANG['ocsconfig'][10]="Globalni uvoz"; 
 $LANG['ocsconfig'][11]="Brez uvoza"; 
