@@ -45,6 +45,7 @@ $LANG['backup'][23]="Fel i MySQL med början i";
 $LANG['backup'][24]="Automatisk omdirigering, om inte klicka"; 
 
 $LANG['bookmark'][1]="bokmärke"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Du har ännu inte skapat några bokmärken."; 
 $LANG['bookmark'][4]="Nytt bokmärke"; 
 $LANG['bookmark'][5]="Publika bokmärken"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Importalternativ"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
 $LANG['ocsconfig'][10]="Global import"; 
 $LANG['ocsconfig'][11]="Ingen import"; 
