@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql hatasının başlangıcı :";
 $LANG['backup'][24]="Otomotik yönlendirme başlıyor, iptal için tıklayınız"; 
 
 $LANG['bookmark'][1]="Yer imi"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="Henüz yerimini kaydetmediniz"; 
 $LANG['bookmark'][4]="Yeni yerimi"; 
 $LANG['bookmark'][5]="Genel yerimleri"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="Seçenekleri İçe Aktar"; 
 $LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
 $LANG['ocsconfig'][10]="Toplu aktarım"; 
 $LANG['ocsconfig'][11]="Aktarılan olmadı."; 
