@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql 错误启动从";
 $LANG['backup'][24]="自动重定向，否则点击"; 
 
 $LANG['bookmark'][1]="书签"; 
+$LANG['bookmark'][2]="Partial load of the bookmark."; 
 $LANG['bookmark'][3]="您尚未设置任何书签"; 
 $LANG['bookmark'][4]="新建书签"; 
 $LANG['bookmark'][5]="公共书签"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG user password";
 $LANG['ocsconfig'][4]="Name of the OCSNG database"; 
 $LANG['ocsconfig'][5]="导入选项"; 
 $LANG['ocsconfig'][6]="忽略OCSNG引入"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="排除下列标签（分隔$,不是对所有）"; 
 $LANG['ocsconfig'][10]="全局导入"; 
 $LANG['ocsconfig'][11]="没有导入"; 
