@@ -45,6 +45,7 @@ $LANG['backup'][23]="Mysql 錯誤從";
 $LANG['backup'][24]="自動重定向，否則點擊"; 
 
 $LANG['bookmark'][1]="書籤"; 
+$LANG['bookmark'][2]="局部載入的書籤"; 
 $LANG['bookmark'][3]="您目前沒有記錄任何書籤."; 
 $LANG['bookmark'][4]="新增書籤"; 
 $LANG['bookmark'][5]="公用書籤"; 
@@ -1131,6 +1132,7 @@ $LANG['ocsconfig'][3]="OCSNG使用者的密碼";
 $LANG['ocsconfig'][4]="OCSNG資料庫名稱"; 
 $LANG['ocsconfig'][5]="導入選項"; 
 $LANG['ocsconfig'][6]="於OCSNG導入忽略"; 
+$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
 $LANG['ocsconfig'][9]="排除下列標籤 (分隔 $, 全部皆否)"; 
 $LANG['ocsconfig'][10]="總體導入"; 
 $LANG['ocsconfig'][11]="沒有導入"; 
