@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: status.php 10412 2010-02-09 08:02:42Z moyo $
+ * @version $Id: status.php 11539 2010-06-05 17:34:49Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2010 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 define('GLPI_ROOT', '.');
-$NEEDED_ITEMS=array("ocsng","user");
+
 include (GLPI_ROOT . "/inc/includes.php");
 
 // Force in normal mode
@@ -52,8 +52,8 @@ $ok_slave=true;
 $ok=true;
 
 // Check slave server connection
-if (isDBSlaveActive()){
-	if (establishDBConnection(true,true,false)){
+if (DBConnection::isDBSlaveActive()){
+	if (DBConnection::establishDBConnection(true,true,false)){
 		echo "GLPI_DBSLAVE_OK\n";
 	} else {
 		echo "GLPI_DBSLAVE_PROBLEM\n";
@@ -64,7 +64,7 @@ if (isDBSlaveActive()){
 }
 
 // Check main server connection
-if (establishDBConnection(false,true,false)){
+if (DBConnection::establishDBConnection(false,true,false)){
 	echo "GLPI_DB_OK\n";
 } else {
 	echo "GLPI_DB_PROBLEM\n";
@@ -76,23 +76,23 @@ $ok = $ok_slave && $ok_master;
 
 // Check session dir (usefull when NFS mounted))
 if (is_dir(GLPI_SESSION_DIR) && is_writable(GLPI_SESSION_DIR)) {
-		echo "GLPI_SESSION_DIR_OK\n";	
+		echo "GLPI_SESSION_DIR_OK\n";
 } else {
 		echo "GLPI_SESSION_DIR_PROBLEM\n";
-		$ok=false;		
+		$ok=false;
 }
 
 // Reestablished DB connection
-if (( $ok_master || $ok_slave ) && establishDBConnection(false,false,false)){
+if (( $ok_master || $ok_slave ) && DBConnection::establishDBConnection(false,false,false)){
 
 	// Check OCS connections
-	$query = "SELECT ID, name FROM glpi_ocs_config";
+	$query = "SELECT id, name FROM glpi_ocsservers";
 	if ($result=$DB->query($query)){
 		if ($DB->numrows($result)){
 			echo "Check OCS servers:";
 			while ($data = $DB->fetch_assoc($result)){
 				echo " ".$data['name'];
-				if (checkOCSconnection($data['ID'])){
+				if (OcsServer::checkOCSconnection($data['id'])){
 					echo "_OK";
 				} else {
 					echo "_PROBLEM";
@@ -104,19 +104,18 @@ if (( $ok_master || $ok_slave ) && establishDBConnection(false,false,false)){
 			echo "No OCS server\n";
 		}
 	}
-	
+
 	// Check Auth connections
-	$auth = new Identification();
+	$auth = new Auth();
 	$auth->getAuthMethods();
-	$ldap_methods = $auth->auth_methods["ldap"];
-		
+	$ldap_methods = $auth->authtypes["ldap"];
+
 	if (count($ldap_methods)){
 		echo "Check LDAP servers:";
 		foreach ($ldap_methods as $method){
 			echo " ".$method['name'];
 
-			if (try_connect_ldap($method['ldap_host'],$method['ldap_port'], 
-				 $method["ldap_rootdn"], $method["ldap_pass"], $method["ldap_use_tls"],"","",$method["ldap_opt_deref"],$method['ID'])){
+			if (AuthLdap::tryToConnectToServer($method, $method["rootdn"], $method["rootdn_password"])){
 				echo "_OK";
 			} else {
 				echo "_PROBLEM";
@@ -132,7 +131,7 @@ if (( $ok_master || $ok_slave ) && establishDBConnection(false,false,false)){
 
 	// TODO check CAS url / check url using socket ?
 
-	
+
 }
 
 echo "\n";
